Class: OpenapiClient::CardInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/card_info.rb

Overview

Card information.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CardInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/openapi_client/models/card_info.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.has_key?(:'brandProductId')
    self.brand_product_id = attributes[:'brandProductId']
  end

  if attributes.has_key?(:'cardFunction')
    self.card_function = attributes[:'cardFunction']
  end

  if attributes.has_key?(:'commercialCard')
    self.commercial_card = attributes[:'commercialCard']
  end

  if attributes.has_key?(:'issuerCountry')
    self.issuer_country = attributes[:'issuerCountry']
  end

  if attributes.has_key?(:'issuerName')
    self.issuer_name = attributes[:'issuerName']
  end
end

Instance Attribute Details

#brand ⇒ Object

The card brand.



19
20
21
# File 'lib/openapi_client/models/card_info.rb', line 19

def brand
  @brand
end

#brand_product_id ⇒ Object

The product ID of the brand.



22
23
24
# File 'lib/openapi_client/models/card_info.rb', line 22

def brand_product_id
  @brand_product_id
end

#card_function ⇒ Object

Returns the value of attribute card_function.



24
25
26
# File 'lib/openapi_client/models/card_info.rb', line 24

def card_function
  @card_function
end

#commercial_card ⇒ Object

Indicates whether it is a corporate or non-corporate card.



27
28
29
# File 'lib/openapi_client/models/card_info.rb', line 27

def commercial_card
  @commercial_card
end

#issuer_country ⇒ Object

The country of the issuer.



30
31
32
# File 'lib/openapi_client/models/card_info.rb', line 30

def issuer_country
  @issuer_country
end

#issuer_name ⇒ Object

The name of the issuer.



33
34
35
# File 'lib/openapi_client/models/card_info.rb', line 33

def issuer_name
  @issuer_name
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/openapi_client/models/card_info.rb', line 58

def self.attribute_map
  {
    :'brand' => :'brand',
    :'brand_product_id' => :'brandProductId',
    :'card_function' => :'cardFunction',
    :'commercial_card' => :'commercialCard',
    :'issuer_country' => :'issuerCountry',
    :'issuer_name' => :'issuerName'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
# File 'lib/openapi_client/models/card_info.rb', line 70

def self.openapi_types
  {
    :'brand' => :'String',
    :'brand_product_id' => :'String',
    :'card_function' => :'CardFunction',
    :'commercial_card' => :'String',
    :'issuer_country' => :'String',
    :'issuer_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



141
142
143
144
145
146
147
148
149
150
# File 'lib/openapi_client/models/card_info.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      brand == o.brand &&
      brand_product_id == o.brand_product_id &&
      card_function == o.card_function &&
      commercial_card == o.commercial_card &&
      issuer_country == o.issuer_country &&
      issuer_name == o.issuer_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/openapi_client/models/card_info.rb', line 188

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/openapi_client/models/card_info.rb', line 254

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/openapi_client/models/card_info.rb', line 167

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/openapi_client/models/card_info.rb', line 154

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



160
161
162
# File 'lib/openapi_client/models/card_info.rb', line 160

def hash
  [brand, brand_product_id, card_function, commercial_card, issuer_country, issuer_name].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
# File 'lib/openapi_client/models/card_info.rb', line 116

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



234
235
236
# File 'lib/openapi_client/models/card_info.rb', line 234

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
# File 'lib/openapi_client/models/card_info.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



228
229
230
# File 'lib/openapi_client/models/card_info.rb', line 228

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



123
124
125
126
127
# File 'lib/openapi_client/models/card_info.rb', line 123

def valid?
  commercial_card_validator = EnumAttributeValidator.new('String', ['CORPORATE', 'NON_CORPORATE'])
  return false unless commercial_card_validator.valid?(@commercial_card)
  true
end