Class: OpenapiClient::Customer

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/customer.rb

Overview

Customer model for customers registered at merchant's website.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Customer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/openapi_client/models/customer.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'startDate')
    self.start_date = attributes[:'startDate']
  end

  if attributes.has_key?(:'firstName')
    self.first_name = attributes[:'firstName']
  end

  if attributes.has_key?(:'lastName')
    self.last_name = attributes[:'lastName']
  end

  if attributes.has_key?(:'middleName')
    self.middle_name = attributes[:'middleName']
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.has_key?(:'sessionId')
    self.session_id = attributes[:'sessionId']
  end

  if attributes.has_key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.has_key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.has_key?(:'dateOfBirth')
    self.date_of_birth = attributes[:'dateOfBirth']
  end

  if attributes.has_key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.has_key?(:'userDefined')
    self.user_defined = attributes[:'userDefined']
  end
end

Instance Attribute Details

#address ⇒ Object

Returns the value of attribute address.



48
49
50
# File 'lib/openapi_client/models/customer.rb', line 48

def address
  @address
end

#date_of_birth ⇒ Object

The customer's year of birth. Format is YYYY.



46
47
48
# File 'lib/openapi_client/models/customer.rb', line 46

def date_of_birth
  @date_of_birth
end

#email ⇒ Object

Customer's email address.



34
35
36
# File 'lib/openapi_client/models/customer.rb', line 34

def email
  @email
end

#first_name ⇒ Object

Customer's first name.



25
26
27
# File 'lib/openapi_client/models/customer.rb', line 25

def first_name
  @first_name
end

#gender ⇒ Object

The customers gender. Do not set this property if the customer does not specify a gender.



43
44
45
# File 'lib/openapi_client/models/customer.rb', line 43

def gender
  @gender
end

#id ⇒ Object

Unique ID for the customer, if registered. This field is required if the parent object is present.



19
20
21
# File 'lib/openapi_client/models/customer.rb', line 19

def id
  @id
end

#last_name ⇒ Object

Customer's last name.



28
29
30
# File 'lib/openapi_client/models/customer.rb', line 28

def last_name
  @last_name
end

#middle_name ⇒ Object

Customer's middle name.



31
32
33
# File 'lib/openapi_client/models/customer.rb', line 31

def middle_name
  @middle_name
end

#session_id ⇒ Object

The unique ID of the current login session. Must be unique for the customer.



37
38
39
# File 'lib/openapi_client/models/customer.rb', line 37

def session_id
  @session_id
end

#start_date ⇒ Object

The timestamp of the customers registration in the merchants platform. Format is YYYY-MM-DD.



22
23
24
# File 'lib/openapi_client/models/customer.rb', line 22

def start_date
  @start_date
end

#user_defined ⇒ Object

A JSON object that can carry any additional information about the customer that might be helpful for fraud detection.



51
52
53
# File 'lib/openapi_client/models/customer.rb', line 51

def user_defined
  @user_defined
end

#username ⇒ Object

The username of this customer in the merchants system. This field should contain customer-supplied data if available instead of a generated ID. This field can contain the clients email address if it is also used for authentication purposes.



40
41
42
# File 'lib/openapi_client/models/customer.rb', line 40

def username
  @username
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/openapi_client/models/customer.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'start_date' => :'startDate',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'middle_name' => :'middleName',
    :'email' => :'email',
    :'session_id' => :'sessionId',
    :'username' => :'username',
    :'gender' => :'gender',
    :'date_of_birth' => :'dateOfBirth',
    :'address' => :'address',
    :'user_defined' => :'userDefined'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/openapi_client/models/customer.rb', line 94

def self.openapi_types
  {
    :'id' => :'String',
    :'start_date' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'middle_name' => :'String',
    :'email' => :'String',
    :'session_id' => :'String',
    :'username' => :'String',
    :'gender' => :'String',
    :'date_of_birth' => :'String',
    :'address' => :'CustomerAddress',
    :'user_defined' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/openapi_client/models/customer.rb', line 200

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      start_date == o.start_date &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      middle_name == o.middle_name &&
      email == o.email &&
      session_id == o.session_id &&
      username == o.username &&
      gender == o.gender &&
      date_of_birth == o.date_of_birth &&
      address == o.address &&
      user_defined == o.user_defined
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/openapi_client/models/customer.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/openapi_client/models/customer.rb', line 319

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/openapi_client/models/customer.rb', line 232

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/openapi_client/models/customer.rb', line 219

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



225
226
227
# File 'lib/openapi_client/models/customer.rb', line 225

def hash
  [id, start_date, first_name, last_name, middle_name, email, session_id, username, gender, date_of_birth, address, user_defined].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
# File 'lib/openapi_client/models/customer.rb', line 170

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



299
300
301
# File 'lib/openapi_client/models/customer.rb', line 299

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
# File 'lib/openapi_client/models/customer.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



293
294
295
# File 'lib/openapi_client/models/customer.rb', line 293

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



181
182
183
184
185
186
# File 'lib/openapi_client/models/customer.rb', line 181

def valid?
  return false if @id.nil?
  gender_validator = EnumAttributeValidator.new('String', ['male', 'female', 'other'])
  return false unless gender_validator.valid?(@gender)
  true
end