Class: OpenapiClient::ExchangeRateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/exchange_rate_response.rb

Overview

Exchange rate response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExchangeRateResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 101

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'clientRequestId')
    self.client_request_id = attributes[:'clientRequestId']
  end

  if attributes.has_key?(:'apiTraceId')
    self.api_trace_id = attributes[:'apiTraceId']
  end

  if attributes.has_key?(:'responseType')
    self.response_type = attributes[:'responseType']
  end

  if attributes.has_key?(:'ipgTransactionId')
    self.ipg_transaction_id = attributes[:'ipgTransactionId']
  end

  if attributes.has_key?(:'requestTime')
    self.request_time = attributes[:'requestTime']
  end

  if attributes.has_key?(:'inquiryRateId')
    self.inquiry_rate_id = attributes[:'inquiryRateId']
  end

  if attributes.has_key?(:'foreignCurrency')
    self.foreign_currency = attributes[:'foreignCurrency']
  end

  if attributes.has_key?(:'foreignAmount')
    self.foreign_amount = attributes[:'foreignAmount']
  end

  if attributes.has_key?(:'exchangeRate')
    self.exchange_rate = attributes[:'exchangeRate']
  end

  if attributes.has_key?(:'dccOffered')
    self.dcc_offered = attributes[:'dccOffered']
  end

  if attributes.has_key?(:'exchangeRateSourceTimestamp')
    self.exchange_rate_source_timestamp = attributes[:'exchangeRateSourceTimestamp']
  end

  if attributes.has_key?(:'expirationTimestamp')
    self.expiration_timestamp = attributes[:'expirationTimestamp']
  end

  if attributes.has_key?(:'marginRatePercentage')
    self.margin_rate_percentage = attributes[:'marginRatePercentage']
  end

  if attributes.has_key?(:'exchangeRateSourceName')
    self.exchange_rate_source_name = attributes[:'exchangeRateSourceName']
  end
end

Instance Attribute Details

#api_trace_id ⇒ Object

Request identifier in API, can be used to request logs from the support team.



22
23
24
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 22

def api_trace_id
  @api_trace_id
end

#client_request_id ⇒ Object

Echoes back the value in the request header for tracking.



19
20
21
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 19

def client_request_id
  @client_request_id
end

#dcc_offered ⇒ Object

Dcc offered.



45
46
47
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 45

def dcc_offered
  @dcc_offered
end

#exchange_rate ⇒ Object

Exchange rate.



42
43
44
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 42

def exchange_rate
  @exchange_rate
end

#exchange_rate_source_name ⇒ Object

Exchange rate source name.



57
58
59
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 57

def exchange_rate_source_name
  @exchange_rate_source_name
end

#exchange_rate_source_timestamp ⇒ Object

Exchange rate source timestamp.



48
49
50
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 48

def exchange_rate_source_timestamp
  @exchange_rate_source_timestamp
end

#expiration_timestamp ⇒ Object

Expiration timestamp.



51
52
53
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 51

def expiration_timestamp
  @expiration_timestamp
end

#foreign_amount ⇒ Object

Foreign amount.



39
40
41
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 39

def foreign_amount
  @foreign_amount
end

#foreign_currency ⇒ Object

Foreign currency in alphabetic ISO 4217 currency code format.



36
37
38
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 36

def foreign_currency
  @foreign_currency
end

#inquiry_rate_id ⇒ Object

Inquiry rate ID.



33
34
35
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 33

def inquiry_rate_id
  @inquiry_rate_id
end

#ipg_transaction_id ⇒ Object

The response transaction ID.



27
28
29
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 27

def ipg_transaction_id
  @ipg_transaction_id
end

#margin_rate_percentage ⇒ Object

Margin rate percentage.



54
55
56
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 54

def margin_rate_percentage
  @margin_rate_percentage
end

#request_time ⇒ Object

Time of the request.



30
31
32
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 30

def request_time
  @request_time
end

#response_type ⇒ Object

Returns the value of attribute response_type.



24
25
26
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 24

def response_type
  @response_type
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 60

def self.attribute_map
  {
    :'client_request_id' => :'clientRequestId',
    :'api_trace_id' => :'apiTraceId',
    :'response_type' => :'responseType',
    :'ipg_transaction_id' => :'ipgTransactionId',
    :'request_time' => :'requestTime',
    :'inquiry_rate_id' => :'inquiryRateId',
    :'foreign_currency' => :'foreignCurrency',
    :'foreign_amount' => :'foreignAmount',
    :'exchange_rate' => :'exchangeRate',
    :'dcc_offered' => :'dccOffered',
    :'exchange_rate_source_timestamp' => :'exchangeRateSourceTimestamp',
    :'expiration_timestamp' => :'expirationTimestamp',
    :'margin_rate_percentage' => :'marginRatePercentage',
    :'exchange_rate_source_name' => :'exchangeRateSourceName'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 80

def self.openapi_types
  {
    :'client_request_id' => :'String',
    :'api_trace_id' => :'String',
    :'response_type' => :'ResponseType',
    :'ipg_transaction_id' => :'String',
    :'request_time' => :'String',
    :'inquiry_rate_id' => :'String',
    :'foreign_currency' => :'String',
    :'foreign_amount' => :'String',
    :'exchange_rate' => :'String',
    :'dcc_offered' => :'String',
    :'exchange_rate_source_timestamp' => :'String',
    :'expiration_timestamp' => :'String',
    :'margin_rate_percentage' => :'String',
    :'exchange_rate_source_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_request_id == o.client_request_id &&
      api_trace_id == o.api_trace_id &&
      response_type == o.response_type &&
      ipg_transaction_id == o.ipg_transaction_id &&
      request_time == o.request_time &&
      inquiry_rate_id == o.inquiry_rate_id &&
      foreign_currency == o.foreign_currency &&
      foreign_amount == o.foreign_amount &&
      exchange_rate == o.exchange_rate &&
      dcc_offered == o.dcc_offered &&
      exchange_rate_source_timestamp == o.exchange_rate_source_timestamp &&
      expiration_timestamp == o.expiration_timestamp &&
      margin_rate_percentage == o.margin_rate_percentage &&
      exchange_rate_source_name == o.exchange_rate_source_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 234

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 300

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 213

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 200

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



206
207
208
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 206

def hash
  [client_request_id, api_trace_id, response_type, ipg_transaction_id, request_time, inquiry_rate_id, foreign_currency, foreign_amount, exchange_rate, dcc_offered, exchange_rate_source_timestamp, expiration_timestamp, margin_rate_percentage, exchange_rate_source_name].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 166

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



280
281
282
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 280

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



274
275
276
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 274

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



173
174
175
# File 'lib/openapi_client/models/exchange_rate_response.rb', line 173

def valid?
  true
end