Class: OpenapiClient::FraudDetectApi
- Inherits:
-
Object
- Object
- OpenapiClient::FraudDetectApi
- Defined in:
- lib/openapi_client/api/fraud_detect_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ FraudDetectApi
constructor
A new instance of FraudDetectApi.
-
#score_only(content_type, client_request_id, api_key, timestamp, score_only_request, opts = {}) ⇒ ScoreOnlyResponse
Score a transaction for fraud.
-
#score_only_with_http_info(content_type, client_request_id, api_key, timestamp, score_only_request, opts = {}) ⇒ Array<(ScoreOnlyResponse, Fixnum, Hash)>
Score a transaction for fraud.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FraudDetectApi
Returns a new instance of FraudDetectApi.
19 20 21 |
# File 'lib/openapi_client/api/fraud_detect_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_client/api/fraud_detect_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#score_only(content_type, client_request_id, api_key, timestamp, score_only_request, opts = {}) ⇒ ScoreOnlyResponse
Score a transaction for fraud. Use this to obtain a fraud score for a transaction.
33 34 35 36 |
# File 'lib/openapi_client/api/fraud_detect_api.rb', line 33 def score_only(content_type, client_request_id, api_key, , score_only_request, opts = {}) data, _status_code, _headers = score_only_with_http_info(content_type, client_request_id, api_key, , score_only_request, opts) data end |
#score_only_with_http_info(content_type, client_request_id, api_key, timestamp, score_only_request, opts = {}) ⇒ Array<(ScoreOnlyResponse, Fixnum, Hash)>
Score a transaction for fraud. Use this to obtain a fraud score for a transaction.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/openapi_client/api/fraud_detect_api.rb', line 49 def score_only_with_http_info(content_type, client_request_id, api_key, , score_only_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FraudDetectApi.score_only ...' end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling FraudDetectApi.score_only" end # verify enum value if @api_client.config.client_side_validation && !['application/json'].include?(content_type) fail ArgumentError, "invalid value for 'content_type', must be one of application/json" end # verify the required parameter 'client_request_id' is set if @api_client.config.client_side_validation && client_request_id.nil? fail ArgumentError, "Missing the required parameter 'client_request_id' when calling FraudDetectApi.score_only" end # verify the required parameter 'api_key' is set if @api_client.config.client_side_validation && api_key.nil? fail ArgumentError, "Missing the required parameter 'api_key' when calling FraudDetectApi.score_only" end # verify the required parameter 'timestamp' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'timestamp' when calling FraudDetectApi.score_only" end # verify the required parameter 'score_only_request' is set if @api_client.config.client_side_validation && score_only_request.nil? fail ArgumentError, "Missing the required parameter 'score_only_request' when calling FraudDetectApi.score_only" end # resource path local_var_path = '/fraud/score-only' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' # header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # header_params[:'Content-Type'] = content_type header_params[:'Client-Request-Id'] = client_request_id header_params[:'Api-Key'] = api_key header_params[:'Timestamp'] = header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil? header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil? # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(score_only_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ScoreOnlyResponse', :default_error_type => 'ErrorResponse', :custom_responses => {400 => 'ScoreOnlyResponse'}) if @api_client.config.debugging @api_client.config.logger.debug "API called: FraudDetectApi#score_only\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |