Class: OpenapiClient::OrderApi
- Inherits:
-
Object
- Object
- OpenapiClient::OrderApi
- Defined in:
- lib/openapi_client/api/order_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ OrderApi
constructor
A new instance of OrderApi.
-
#order_inquiry(content_type, client_request_id, api_key, timestamp, order_id, opts = {}) ⇒ OrderResponse
Retrieve the state of an order.
-
#order_inquiry_with_http_info(content_type, client_request_id, api_key, timestamp, order_id, opts = {}) ⇒ Array<(OrderResponse, Fixnum, Hash)>
Retrieve the state of an order.
-
#submit_secondary_transaction_from_order(content_type, client_request_id, api_key, timestamp, order_id, secondary_transaction, opts = {}) ⇒ TransactionResponse
Perform return or postAuth secondary transactions.
-
#submit_secondary_transaction_from_order_with_http_info(content_type, client_request_id, api_key, timestamp, order_id, secondary_transaction, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>
Perform return or postAuth secondary transactions.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_client/api/order_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#order_inquiry(content_type, client_request_id, api_key, timestamp, order_id, opts = {}) ⇒ OrderResponse
Retrieve the state of an order. Use this query to get the current state of an existing order.
34 35 36 37 |
# File 'lib/openapi_client/api/order_api.rb', line 34 def order_inquiry(content_type, client_request_id, api_key, , order_id, opts = {}) data, _status_code, _headers = order_inquiry_with_http_info(content_type, client_request_id, api_key, , order_id, opts) data end |
#order_inquiry_with_http_info(content_type, client_request_id, api_key, timestamp, order_id, opts = {}) ⇒ Array<(OrderResponse, Fixnum, Hash)>
Retrieve the state of an order. Use this query to get the current state of an existing order.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/openapi_client/api/order_api.rb', line 51 def order_inquiry_with_http_info(content_type, client_request_id, api_key, , order_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrderApi.order_inquiry ...' end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling OrderApi.order_inquiry" end # verify enum value if @api_client.config.client_side_validation && !['application/json'].include?(content_type) fail ArgumentError, "invalid value for 'content_type', must be one of application/json" end # verify the required parameter 'client_request_id' is set if @api_client.config.client_side_validation && client_request_id.nil? fail ArgumentError, "Missing the required parameter 'client_request_id' when calling OrderApi.order_inquiry" end # verify the required parameter 'api_key' is set if @api_client.config.client_side_validation && api_key.nil? fail ArgumentError, "Missing the required parameter 'api_key' when calling OrderApi.order_inquiry" end # verify the required parameter 'timestamp' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'timestamp' when calling OrderApi.order_inquiry" end # verify the required parameter 'order_id' is set if @api_client.config.client_side_validation && order_id.nil? fail ArgumentError, "Missing the required parameter 'order_id' when calling OrderApi.order_inquiry" end # resource path local_var_path = '/orders/{order-id}'.sub('{' + 'order-id' + '}', order_id.to_s) # query parameters query_params = {} query_params[:'storeId'] = opts[:'store_id'] if !opts[:'store_id'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # header_params[:'Content-Type'] = content_type header_params[:'Client-Request-Id'] = client_request_id header_params[:'Api-Key'] = api_key header_params[:'Timestamp'] = header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil? header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil? # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrderResponse', :default_error_type => 'ErrorResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrderApi#order_inquiry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#submit_secondary_transaction_from_order(content_type, client_request_id, api_key, timestamp, order_id, secondary_transaction, opts = {}) ⇒ TransactionResponse
Perform return or postAuth secondary transactions. Use this to perform a postAuth or return secondary transaction using order ID. Partial postAuths and returns are allowed.
129 130 131 132 |
# File 'lib/openapi_client/api/order_api.rb', line 129 def submit_secondary_transaction_from_order(content_type, client_request_id, api_key, , order_id, secondary_transaction, opts = {}) data, _status_code, _headers = submit_secondary_transaction_from_order_with_http_info(content_type, client_request_id, api_key, , order_id, secondary_transaction, opts) data end |
#submit_secondary_transaction_from_order_with_http_info(content_type, client_request_id, api_key, timestamp, order_id, secondary_transaction, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>
Perform return or postAuth secondary transactions. Use this to perform a postAuth or return secondary transaction using order ID. Partial postAuths and returns are allowed.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/openapi_client/api/order_api.rb', line 146 def submit_secondary_transaction_from_order_with_http_info(content_type, client_request_id, api_key, , order_id, secondary_transaction, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrderApi.submit_secondary_transaction_from_order ...' end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling OrderApi.submit_secondary_transaction_from_order" end # verify enum value if @api_client.config.client_side_validation && !['application/json'].include?(content_type) fail ArgumentError, "invalid value for 'content_type', must be one of application/json" end # verify the required parameter 'client_request_id' is set if @api_client.config.client_side_validation && client_request_id.nil? fail ArgumentError, "Missing the required parameter 'client_request_id' when calling OrderApi.submit_secondary_transaction_from_order" end # verify the required parameter 'api_key' is set if @api_client.config.client_side_validation && api_key.nil? fail ArgumentError, "Missing the required parameter 'api_key' when calling OrderApi.submit_secondary_transaction_from_order" end # verify the required parameter 'timestamp' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'timestamp' when calling OrderApi.submit_secondary_transaction_from_order" end # verify the required parameter 'order_id' is set if @api_client.config.client_side_validation && order_id.nil? fail ArgumentError, "Missing the required parameter 'order_id' when calling OrderApi.submit_secondary_transaction_from_order" end # verify the required parameter 'secondary_transaction' is set if @api_client.config.client_side_validation && secondary_transaction.nil? fail ArgumentError, "Missing the required parameter 'secondary_transaction' when calling OrderApi.submit_secondary_transaction_from_order" end # resource path local_var_path = '/orders/{order-id}'.sub('{' + 'order-id' + '}', order_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' # header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # header_params[:'Content-Type'] = content_type header_params[:'Client-Request-Id'] = client_request_id header_params[:'Api-Key'] = api_key header_params[:'Timestamp'] = header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil? header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil? # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(secondary_transaction) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'TransactionResponse', :default_error_type => 'ErrorResponse', :error_type => 'TransactionErrorResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrderApi#submit_secondary_transaction_from_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |