Class: OpenapiClient::PaymentApi

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/api/payment_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentApi

Returns a new instance of PaymentApi.



19
20
21
# File 'lib/openapi_client/api/payment_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/openapi_client/api/payment_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#finalize_secure_transaction(content_type, client_request_id, api_key, timestamp, transaction_id, authentication_verification_request, opts = {}) ⇒ TransactionResponse

Update a 3DSecure or UnionPay payment and continue processing. Use this to handle a 3DSecure redirect response or UnionPay authentication, updating the transaction and continuing processing.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • authentication_verification_request —

    Accepted request types: Secure3dAuthenticationVerificationRequest and UnionPayAuthenticationVerificationRequest.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

Returns:



34
35
36
37
# File 'lib/openapi_client/api/payment_api.rb', line 34

def finalize_secure_transaction(content_type, client_request_id, api_key, timestamp, transaction_id, authentication_verification_request, opts = {})
  data, _status_code, _headers = finalize_secure_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, authentication_verification_request, opts)
  data
end

#finalize_secure_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, authentication_verification_request, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>

Update a 3DSecure or UnionPay payment and continue processing. Use this to handle a 3DSecure redirect response or UnionPay authentication, updating the transaction and continuing processing.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • authentication_verification_request —

    Accepted request types: Secure3dAuthenticationVerificationRequest and UnionPayAuthenticationVerificationRequest.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

Returns:

  • (Array<(TransactionResponse, Fixnum, Hash)>) —

    TransactionResponse data, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/openapi_client/api/payment_api.rb', line 51

def finalize_secure_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, authentication_verification_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.finalize_secure_transaction ...'
  end
  # verify the required parameter 'content_type' is set
  if @api_client.config.client_side_validation && content_type.nil?
    fail ArgumentError, "Missing the required parameter 'content_type' when calling PaymentApi.finalize_secure_transaction"
  end
  # verify enum value
  if @api_client.config.client_side_validation && !['application/json'].include?(content_type)
    fail ArgumentError, "invalid value for 'content_type', must be one of application/json"
  end
  # verify the required parameter 'client_request_id' is set
  if @api_client.config.client_side_validation && client_request_id.nil?
    fail ArgumentError, "Missing the required parameter 'client_request_id' when calling PaymentApi.finalize_secure_transaction"
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling PaymentApi.finalize_secure_transaction"
  end
  # verify the required parameter 'timestamp' is set
  if @api_client.config.client_side_validation && timestamp.nil?
    fail ArgumentError, "Missing the required parameter 'timestamp' when calling PaymentApi.finalize_secure_transaction"
  end
  # verify the required parameter 'transaction_id' is set
  if @api_client.config.client_side_validation && transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'transaction_id' when calling PaymentApi.finalize_secure_transaction"
  end
  # verify the required parameter 'authentication_verification_request' is set
  if @api_client.config.client_side_validation && authentication_verification_request.nil?
    fail ArgumentError, "Missing the required parameter 'authentication_verification_request' when calling PaymentApi.finalize_secure_transaction"
  end
  # resource path
  local_var_path = '/payments/{transaction-id}'.sub('{' + 'transaction-id' + '}', transaction_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  # header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  # header_params[:'Content-Type'] = content_type
  header_params[:'Client-Request-Id'] = client_request_id
  header_params[:'Api-Key'] = api_key
  header_params[:'Timestamp'] = timestamp
  header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil?
  header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(authentication_verification_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TransactionResponse',
    :default_error_type => 'ErrorResponse',
    :error_type => 'TransactionErrorResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#finalize_secure_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#submit_primary_transaction(content_type, client_request_id, api_key, timestamp, primary_transaction, opts = {}) ⇒ TransactionResponse

Generate a primary transaction. Use this to originate a financial transaction like a sale, preauthorization, or credit.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • primary_transaction —

    Accepted request types: AliPaySaleTransaction, ChinaPnRSaleTransaction, PaymentCardCreditTransaction, PaymentCardForcedTicketTransaction, PaymentCardSaleTransaction, PaymentCardPreAuthTransaction, PaymentCardPayerAuthTransaction, PaymentTokenCreditTransaction, PaymentTokenPreAuthTransaction, PaymentTokenSaleTransaction, PaypalCreditTransaction, and SepaSaleTransaction.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

Returns:



134
135
136
137
# File 'lib/openapi_client/api/payment_api.rb', line 134

def submit_primary_transaction(content_type, client_request_id, api_key, timestamp, primary_transaction, opts = {})
  data, _status_code, _headers = submit_primary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, primary_transaction, opts)
  data
end

#submit_primary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, primary_transaction, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>

Generate a primary transaction. Use this to originate a financial transaction like a sale, preauthorization, or credit.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • primary_transaction —

    Accepted request types: AliPaySaleTransaction, ChinaPnRSaleTransaction, PaymentCardCreditTransaction, PaymentCardForcedTicketTransaction, PaymentCardSaleTransaction, PaymentCardPreAuthTransaction, PaymentCardPayerAuthTransaction, PaymentTokenCreditTransaction, PaymentTokenPreAuthTransaction, PaymentTokenSaleTransaction, PaypalCreditTransaction, and SepaSaleTransaction.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

Returns:

  • (Array<(TransactionResponse, Fixnum, Hash)>) —

    TransactionResponse data, response status code and response headers



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/openapi_client/api/payment_api.rb', line 150

def submit_primary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, primary_transaction, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.submit_primary_transaction ...'
  end
  # verify the required parameter 'content_type' is set
  if @api_client.config.client_side_validation && content_type.nil?
    fail ArgumentError, "Missing the required parameter 'content_type' when calling PaymentApi.submit_primary_transaction"
  end
  # verify enum value
  if @api_client.config.client_side_validation && !['application/json'].include?(content_type)
    fail ArgumentError, "invalid value for 'content_type', must be one of application/json"
  end
  # verify the required parameter 'client_request_id' is set
  if @api_client.config.client_side_validation && client_request_id.nil?
    fail ArgumentError, "Missing the required parameter 'client_request_id' when calling PaymentApi.submit_primary_transaction"
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling PaymentApi.submit_primary_transaction"
  end
  # verify the required parameter 'timestamp' is set
  if @api_client.config.client_side_validation && timestamp.nil?
    fail ArgumentError, "Missing the required parameter 'timestamp' when calling PaymentApi.submit_primary_transaction"
  end
  # verify the required parameter 'primary_transaction' is set
  if @api_client.config.client_side_validation && primary_transaction.nil?
    fail ArgumentError, "Missing the required parameter 'primary_transaction' when calling PaymentApi.submit_primary_transaction"
  end
  # resource path
  local_var_path = '/payments'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  # header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  # header_params[:'Content-Type'] = content_type
  header_params[:'Client-Request-Id'] = client_request_id
  header_params[:'Api-Key'] = api_key
  header_params[:'Timestamp'] = timestamp
  header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil?
  header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(primary_transaction)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TransactionResponse',
    :default_error_type => 'ErrorResponse',
    :error_type => 'TransactionErrorResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#submit_primary_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#submit_secondary_transaction(content_type, client_request_id, api_key, timestamp, transaction_id, secondary_transaction, opts = {}) ⇒ TransactionResponse

Perform a secondary transaction. Use this to perform a void, postAuth or return secondary transaction. Partial postAuths and returns are allowed.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • secondary_transaction —

    Accepted request types: PostAuthTransaction, VoidTransaction, and ReturnTransaction.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

  • :store_id (String) —

    An optional outlet ID for clients that support multiple stores in the same developer app.

Returns:



231
232
233
234
# File 'lib/openapi_client/api/payment_api.rb', line 231

def submit_secondary_transaction(content_type, client_request_id, api_key, timestamp, transaction_id, secondary_transaction, opts = {})
  data, _status_code, _headers = submit_secondary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, secondary_transaction, opts)
  data
end

#submit_secondary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, secondary_transaction, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>

Perform a secondary transaction. Use this to perform a void, postAuth or return secondary transaction. Partial postAuths and returns are allowed.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • secondary_transaction —

    Accepted request types: PostAuthTransaction, VoidTransaction, and ReturnTransaction.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

  • :store_id (String) —

    An optional outlet ID for clients that support multiple stores in the same developer app.

Returns:

  • (Array<(TransactionResponse, Fixnum, Hash)>) —

    TransactionResponse data, response status code and response headers



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/openapi_client/api/payment_api.rb', line 249

def submit_secondary_transaction_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, secondary_transaction, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.submit_secondary_transaction ...'
  end
  # verify the required parameter 'content_type' is set
  if @api_client.config.client_side_validation && content_type.nil?
    fail ArgumentError, "Missing the required parameter 'content_type' when calling PaymentApi.submit_secondary_transaction"
  end
  # verify enum value
  if @api_client.config.client_side_validation && !['application/json'].include?(content_type)
    fail ArgumentError, "invalid value for 'content_type', must be one of application/json"
  end
  # verify the required parameter 'client_request_id' is set
  if @api_client.config.client_side_validation && client_request_id.nil?
    fail ArgumentError, "Missing the required parameter 'client_request_id' when calling PaymentApi.submit_secondary_transaction"
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling PaymentApi.submit_secondary_transaction"
  end
  # verify the required parameter 'timestamp' is set
  if @api_client.config.client_side_validation && timestamp.nil?
    fail ArgumentError, "Missing the required parameter 'timestamp' when calling PaymentApi.submit_secondary_transaction"
  end
  # verify the required parameter 'transaction_id' is set
  if @api_client.config.client_side_validation && transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'transaction_id' when calling PaymentApi.submit_secondary_transaction"
  end
  # verify the required parameter 'secondary_transaction' is set
  if @api_client.config.client_side_validation && secondary_transaction.nil?
    fail ArgumentError, "Missing the required parameter 'secondary_transaction' when calling PaymentApi.submit_secondary_transaction"
  end
  # resource path
  local_var_path = '/payments/{transaction-id}'.sub('{' + 'transaction-id' + '}', transaction_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'storeId'] = opts[:'store_id'] if !opts[:'store_id'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  # header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  # header_params[:'Content-Type'] = content_type
  header_params[:'Client-Request-Id'] = client_request_id
  header_params[:'Api-Key'] = api_key
  header_params[:'Timestamp'] = timestamp
  header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil?
  header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(secondary_transaction)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TransactionResponse',
    :default_error_type => 'ErrorResponse',
    :error_type => 'TransactionErrorResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#submit_secondary_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#transaction_inquiry(content_type, client_request_id, api_key, timestamp, transaction_id, opts = {}) ⇒ TransactionResponse

Retrieve the state of a transaction. Use this query to get the current state of an existing transaction.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

  • :store_id (String) —

    An optional outlet ID for clients that support multiple stores in the same developer app.

Returns:



334
335
336
337
# File 'lib/openapi_client/api/payment_api.rb', line 334

def transaction_inquiry(content_type, client_request_id, api_key, timestamp, transaction_id, opts = {})
  data, _status_code, _headers = transaction_inquiry_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, opts)
  data
end

#transaction_inquiry_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, opts = {}) ⇒ Array<(TransactionResponse, Fixnum, Hash)>

Retrieve the state of a transaction. Use this query to get the current state of an existing transaction.

Parameters:

  • content_type —

    Content type.

  • client_request_id —

    A client-generated ID for request tracking and signature creation, unique per request. This is also used for idempotency control. We recommend 128-bit UUID format.

  • api_key —

    Key given to merchant after boarding associating their requests with the appropriate app in Apigee.

  • timestamp —

    Epoch timestamp in milliseconds in the request from a client system. Used for Message Signature generation and time limit (5 mins).

  • transaction_id —

    Gateway transaction identifier as returned in the parameter ipgTransactionId.

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :message_signature (String) —

    Used to ensure the request has not been tampered with during transmission. The Message-Signature is the Base64 encoded HMAC hash (SHA256 algorithm with the API Secret as the key.) For more information, refer to the supporting documentation on the Developer Portal.

  • :region (String) —

    Indicates the region where the client wants the transaction to be processed. This will override the default processing region identified for the client. Available options are argentina, brazil, germany, india and northamerica. Region specific store setup and APIGEE boarding is required in order to use an alternate region for processing.

  • :store_id (String) —

    An optional outlet ID for clients that support multiple stores in the same developer app.

Returns:

  • (Array<(TransactionResponse, Fixnum, Hash)>) —

    TransactionResponse data, response status code and response headers



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/openapi_client/api/payment_api.rb', line 351

def transaction_inquiry_with_http_info(content_type, client_request_id, api_key, timestamp, transaction_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.transaction_inquiry ...'
  end
  # verify the required parameter 'content_type' is set
  if @api_client.config.client_side_validation && content_type.nil?
    fail ArgumentError, "Missing the required parameter 'content_type' when calling PaymentApi.transaction_inquiry"
  end
  # verify enum value
  if @api_client.config.client_side_validation && !['application/json'].include?(content_type)
    fail ArgumentError, "invalid value for 'content_type', must be one of application/json"
  end
  # verify the required parameter 'client_request_id' is set
  if @api_client.config.client_side_validation && client_request_id.nil?
    fail ArgumentError, "Missing the required parameter 'client_request_id' when calling PaymentApi.transaction_inquiry"
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling PaymentApi.transaction_inquiry"
  end
  # verify the required parameter 'timestamp' is set
  if @api_client.config.client_side_validation && timestamp.nil?
    fail ArgumentError, "Missing the required parameter 'timestamp' when calling PaymentApi.transaction_inquiry"
  end
  # verify the required parameter 'transaction_id' is set
  if @api_client.config.client_side_validation && transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'transaction_id' when calling PaymentApi.transaction_inquiry"
  end
  # resource path
  local_var_path = '/payments/{transaction-id}'.sub('{' + 'transaction-id' + '}', transaction_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'storeId'] = opts[:'store_id'] if !opts[:'store_id'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # header_params[:'Content-Type'] = content_type
  header_params[:'Client-Request-Id'] = client_request_id
  header_params[:'Api-Key'] = api_key
  header_params[:'Timestamp'] = timestamp
  header_params[:'Message-Signature'] = opts[:'message_signature'] if !opts[:'message_signature'].nil?
  header_params[:'Region'] = opts[:'region'] if !opts[:'region'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TransactionResponse',
    :default_error_type => 'ErrorResponse',
    :error_type => 'TransactionErrorResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#transaction_inquiry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end