Class: OpenapiClient::PaymentCardCreditTransaction
- Inherits:
-
Object
- Object
- OpenapiClient::PaymentCardCreditTransaction
- Defined in:
- lib/openapi_client/models/payment_card_credit_transaction.rb
Overview
Request to create credit transaction using payment card.
Instance Attribute Summary collapse
-
#currency_conversion ⇒ Object
Returns the value of attribute currency_conversion.
-
#merchant_transaction_id ⇒ Object
The unique merchant transaction ID from the request header, if supplied.
-
#order ⇒ Object
Returns the value of attribute order.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
-
#request_type ⇒ Object
Object name of the primary transaction request.
-
#store_id ⇒ Object
An optional outlet ID for clients that support multiple stores in the same app.
-
#transaction_amount ⇒ Object
Returns the value of attribute transaction_amount.
-
#transaction_origin ⇒ Object
Returns the value of attribute transaction_origin.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentCardCreditTransaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentCardCreditTransaction
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'requestType') self.request_type = attributes[:'requestType'] end if attributes.has_key?(:'storeId') self.store_id = attributes[:'storeId'] end if attributes.has_key?(:'merchantTransactionId') self.merchant_transaction_id = attributes[:'merchantTransactionId'] end if attributes.has_key?(:'transactionAmount') self.transaction_amount = attributes[:'transactionAmount'] end if attributes.has_key?(:'transactionOrigin') self.transaction_origin = attributes[:'transactionOrigin'] end if attributes.has_key?(:'order') self.order = attributes[:'order'] end if attributes.has_key?(:'paymentMethod') self.payment_method = attributes[:'paymentMethod'] end if attributes.has_key?(:'currencyConversion') self.currency_conversion = attributes[:'currencyConversion'] end end |
Instance Attribute Details
#currency_conversion ⇒ Object
Returns the value of attribute currency_conversion.
35 36 37 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 35 def currency_conversion @currency_conversion end |
#merchant_transaction_id ⇒ Object
The unique merchant transaction ID from the request header, if supplied.
25 26 27 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 25 def merchant_transaction_id @merchant_transaction_id end |
#order ⇒ Object
Returns the value of attribute order.
31 32 33 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 31 def order @order end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
33 34 35 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 33 def payment_method @payment_method end |
#request_type ⇒ Object
Object name of the primary transaction request.
19 20 21 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 19 def request_type @request_type end |
#store_id ⇒ Object
An optional outlet ID for clients that support multiple stores in the same app.
22 23 24 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 22 def store_id @store_id end |
#transaction_amount ⇒ Object
Returns the value of attribute transaction_amount.
27 28 29 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 27 def transaction_amount @transaction_amount end |
#transaction_origin ⇒ Object
Returns the value of attribute transaction_origin.
29 30 31 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 29 def transaction_origin @transaction_origin end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 38 def self.attribute_map { :'request_type' => :'requestType', :'store_id' => :'storeId', :'merchant_transaction_id' => :'merchantTransactionId', :'transaction_amount' => :'transactionAmount', :'transaction_origin' => :'transactionOrigin', :'order' => :'order', :'payment_method' => :'paymentMethod', :'currency_conversion' => :'currencyConversion' } end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 52 def self.openapi_types { :'request_type' => :'String', :'store_id' => :'String', :'merchant_transaction_id' => :'String', :'transaction_amount' => :'Amount', :'transaction_origin' => :'TransactionOrigin', :'order' => :'Order', :'payment_method' => :'PaymentCardPaymentMethod', :'currency_conversion' => :'CurrencyConversion' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && request_type == o.request_type && store_id == o.store_id && merchant_transaction_id == o.merchant_transaction_id && transaction_amount == o.transaction_amount && transaction_origin == o.transaction_origin && order == o.order && payment_method == o.payment_method && currency_conversion == o.currency_conversion end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 215 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 281 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 187 def hash [request_type, store_id, merchant_transaction_id, transaction_amount, transaction_origin, order, payment_method, currency_conversion].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 108 def list_invalid_properties invalid_properties = Array.new if @request_type.nil? invalid_properties.push('invalid value for "request_type", request_type cannot be nil.') end if !@store_id.nil? && @store_id.to_s.length > 20 invalid_properties.push('invalid value for "store_id", the character length must be smaller than or equal to 20.') end if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40 invalid_properties.push('invalid value for "merchant_transaction_id", the character length must be smaller than or equal to 40.') end if @transaction_amount.nil? invalid_properties.push('invalid value for "transaction_amount", transaction_amount cannot be nil.') end if @payment_method.nil? invalid_properties.push('invalid value for "payment_method", payment_method cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
261 262 263 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 261 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
255 256 257 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 255 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 141 142 |
# File 'lib/openapi_client/models/payment_card_credit_transaction.rb', line 135 def valid? return false if @request_type.nil? return false if !@store_id.nil? && @store_id.to_s.length > 20 return false if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40 return false if @transaction_amount.nil? return false if @payment_method.nil? true end |