Class: OpenapiClient::PaymentCardForcedTicketTransaction

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/payment_card_forced_ticket_transaction.rb

Overview

Request to create forced ticket primary transaction.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentCardForcedTicketTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'requestType')
    self.request_type = attributes[:'requestType']
  end

  if attributes.has_key?(:'storeId')
    self.store_id = attributes[:'storeId']
  end

  if attributes.has_key?(:'merchantTransactionId')
    self.merchant_transaction_id = attributes[:'merchantTransactionId']
  end

  if attributes.has_key?(:'transactionAmount')
    self.transaction_amount = attributes[:'transactionAmount']
  end

  if attributes.has_key?(:'transactionOrigin')
    self.transaction_origin = attributes[:'transactionOrigin']
  end

  if attributes.has_key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.has_key?(:'paymentMethod')
    self.payment_method = attributes[:'paymentMethod']
  end

  if attributes.has_key?(:'referenceNumber')
    self.reference_number = attributes[:'referenceNumber']
  end
end

Instance Attribute Details

#merchant_transaction_id ⇒ Object

The unique merchant transaction ID from the request header, if supplied.



25
26
27
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 25

def merchant_transaction_id
  @merchant_transaction_id
end

#order ⇒ Object

Returns the value of attribute order.



31
32
33
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 31

def order
  @order
end

#payment_method ⇒ Object

Returns the value of attribute payment_method.



33
34
35
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 33

def payment_method
  @payment_method
end

#reference_number ⇒ Object

Stores the six-digit reference number you have received as the result of a successful external authorization (e.g. by phone). The gateway needs this number for uniquely mapping a ForcedTicket transaction to a previously performed external authorization.



36
37
38
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 36

def reference_number
  @reference_number
end

#request_type ⇒ Object

Object name of the primary transaction request.



19
20
21
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 19

def request_type
  @request_type
end

#store_id ⇒ Object

An optional outlet ID for clients that support multiple stores in the same app.



22
23
24
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 22

def store_id
  @store_id
end

#transaction_amount ⇒ Object

Returns the value of attribute transaction_amount.



27
28
29
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 27

def transaction_amount
  @transaction_amount
end

#transaction_origin ⇒ Object

Returns the value of attribute transaction_origin.



29
30
31
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 29

def transaction_origin
  @transaction_origin
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 39

def self.attribute_map
  {
    :'request_type' => :'requestType',
    :'store_id' => :'storeId',
    :'merchant_transaction_id' => :'merchantTransactionId',
    :'transaction_amount' => :'transactionAmount',
    :'transaction_origin' => :'transactionOrigin',
    :'order' => :'order',
    :'payment_method' => :'paymentMethod',
    :'reference_number' => :'referenceNumber'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 53

def self.openapi_types
  {
    :'request_type' => :'String',
    :'store_id' => :'String',
    :'merchant_transaction_id' => :'String',
    :'transaction_amount' => :'Amount',
    :'transaction_origin' => :'TransactionOrigin',
    :'order' => :'Order',
    :'payment_method' => :'PaymentCardPaymentMethod',
    :'reference_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      request_type == o.request_type &&
      store_id == o.store_id &&
      merchant_transaction_id == o.merchant_transaction_id &&
      transaction_amount == o.transaction_amount &&
      transaction_origin == o.transaction_origin &&
      order == o.order &&
      payment_method == o.payment_method &&
      reference_number == o.reference_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 240

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 306

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 219

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 206

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



212
213
214
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 212

def hash
  [request_type, store_id, merchant_transaction_id, transaction_amount, transaction_origin, order, payment_method, reference_number].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 109

def list_invalid_properties
  invalid_properties = Array.new
  if @request_type.nil?
    invalid_properties.push('invalid value for "request_type", request_type cannot be nil.')
  end

  if !@store_id.nil? && @store_id.to_s.length > 20
    invalid_properties.push('invalid value for "store_id", the character length must be smaller than or equal to 20.')
  end

  if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40
    invalid_properties.push('invalid value for "merchant_transaction_id", the character length must be smaller than or equal to 40.')
  end

  if @transaction_amount.nil?
    invalid_properties.push('invalid value for "transaction_amount", transaction_amount cannot be nil.')
  end

  if @payment_method.nil?
    invalid_properties.push('invalid value for "payment_method", payment_method cannot be nil.')
  end

  if @reference_number.nil?
    invalid_properties.push('invalid value for "reference_number", reference_number cannot be nil.')
  end

  if @reference_number.to_s.length > 8
    invalid_properties.push('invalid value for "reference_number", the character length must be smaller than or equal to 8.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



286
287
288
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 286

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



280
281
282
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 280

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



144
145
146
147
148
149
150
151
152
153
# File 'lib/openapi_client/models/payment_card_forced_ticket_transaction.rb', line 144

def valid?
  return false if @request_type.nil?
  return false if !@store_id.nil? && @store_id.to_s.length > 20
  return false if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40
  return false if @transaction_amount.nil?
  return false if @payment_method.nil?
  return false if @reference_number.nil?
  return false if @reference_number.to_s.length > 8
  true
end