Class: OpenapiClient::PaymentDeviceDisbursementTransaction

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/payment_device_disbursement_transaction.rb

Overview

Request to create disbursement transaction using decrypted card details from payment device. The transaction origin will be fixed as PHONE when data is manually entered into the device and as RETAIL when data is entered into the device via swipe.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentDeviceDisbursementTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::PaymentDeviceDisbursementTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::PaymentDeviceDisbursementTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'request_type')
    self.request_type = attributes[:'request_type']
  end

  if attributes.key?(:'transaction_amount')
    self.transaction_amount = attributes[:'transaction_amount']
  end

  if attributes.key?(:'store_id')
    self.store_id = attributes[:'store_id']
  end

  if attributes.key?(:'merchant_transaction_id')
    self.merchant_transaction_id = attributes[:'merchant_transaction_id']
  end

  if attributes.key?(:'transaction_origin')
    self.transaction_origin = attributes[:'transaction_origin']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'disbursement')
    self.disbursement = attributes[:'disbursement']
  end
end

Instance Attribute Details

#disbursementObject

Returns the value of attribute disbursement.



35
36
37
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 35

def disbursement
  @disbursement
end

#merchant_transaction_idObject

The unique merchant transaction ID from the request header, if supplied.



27
28
29
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 27

def merchant_transaction_id
  @merchant_transaction_id
end

#orderObject

Returns the value of attribute order.



31
32
33
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 31

def order
  @order
end

#payment_methodObject

Returns the value of attribute payment_method.



33
34
35
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 33

def payment_method
  @payment_method
end

#request_typeObject

Object name of the primary transaction request.



19
20
21
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 19

def request_type
  @request_type
end

#store_idObject

An optional outlet ID for clients that support multiple stores in the same app.



24
25
26
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 24

def store_id
  @store_id
end

#transaction_amountObject

Returns the value of attribute transaction_amount.



21
22
23
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 21

def transaction_amount
  @transaction_amount
end

#transaction_originObject

Returns the value of attribute transaction_origin.



29
30
31
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 29

def transaction_origin
  @transaction_origin
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 38

def self.attribute_map
  {
    :'request_type' => :'requestType',
    :'transaction_amount' => :'transactionAmount',
    :'store_id' => :'storeId',
    :'merchant_transaction_id' => :'merchantTransactionId',
    :'transaction_origin' => :'transactionOrigin',
    :'order' => :'order',
    :'payment_method' => :'paymentMethod',
    :'disbursement' => :'disbursement'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 214

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



66
67
68
69
70
71
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 66

def self.openapi_all_of
  [
  :'PaymentDeviceDisbursementTransactionAllOf',
  :'PrimaryTransaction'
  ]
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 52

def self.openapi_types
  {
    :'request_type' => :'String',
    :'transaction_amount' => :'Amount',
    :'store_id' => :'String',
    :'merchant_transaction_id' => :'String',
    :'transaction_origin' => :'TransactionOrigin',
    :'order' => :'Order',
    :'payment_method' => :'PaymentDevicePaymentMethod',
    :'disbursement' => :'Disbursement'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      request_type == o.request_type &&
      transaction_amount == o.transaction_amount &&
      store_id == o.store_id &&
      merchant_transaction_id == o.merchant_transaction_id &&
      transaction_origin == o.transaction_origin &&
      order == o.order &&
      payment_method == o.payment_method &&
      disbursement == o.disbursement
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 242

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OpenapiClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 307

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 207

def hash
  [request_type, transaction_amount, store_id, merchant_transaction_id, transaction_origin, order, payment_method, disbursement].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 123

def list_invalid_properties
  invalid_properties = Array.new
  if @request_type.nil?
    invalid_properties.push('invalid value for "request_type", request_type cannot be nil.')
  end

  if @transaction_amount.nil?
    invalid_properties.push('invalid value for "transaction_amount", transaction_amount cannot be nil.')
  end

  if !@store_id.nil? && @store_id.to_s.length > 20
    invalid_properties.push('invalid value for "store_id", the character length must be smaller than or equal to 20.')
  end

  if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40
    invalid_properties.push('invalid value for "merchant_transaction_id", the character length must be smaller than or equal to 40.')
  end

  if @payment_method.nil?
    invalid_properties.push('invalid value for "payment_method", payment_method cannot be nil.')
  end

  if @disbursement.nil?
    invalid_properties.push('invalid value for "disbursement", disbursement cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 287

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 281

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
# File 'lib/openapi_client/models/payment_device_disbursement_transaction.rb', line 154

def valid?
  return false if @request_type.nil?
  return false if @transaction_amount.nil?
  return false if !@store_id.nil? && @store_id.to_s.length > 20
  return false if !@merchant_transaction_id.nil? && @merchant_transaction_id.to_s.length > 40
  return false if @payment_method.nil?
  return false if @disbursement.nil?
  true
end