Class: OpenapiClient::PaymentSchedulesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/payment_schedules_request.rb

Overview

Request to create a gateway schedule. Abstract class, do not use this class directly, use one of its children.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentSchedulesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 106

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'requestType')
    self.request_type = attributes[:'requestType']
  end

  if attributes.has_key?(:'storeId')
    self.store_id = attributes[:'storeId']
  end

  if attributes.has_key?(:'startDate')
    self.start_date = attributes[:'startDate']
  end

  if attributes.has_key?(:'numberOfPayments')
    self.number_of_payments = attributes[:'numberOfPayments']
  end

  if attributes.has_key?(:'maximumFailures')
    self.maximum_failures = attributes[:'maximumFailures']
  end

  if attributes.has_key?(:'invoiceNumber')
    self.invoice_number = attributes[:'invoiceNumber']
  end

  if attributes.has_key?(:'purchaseOrderNumber')
    self.purchase_order_number = attributes[:'purchaseOrderNumber']
  end

  if attributes.has_key?(:'transactionOrigin')
    self.transaction_origin = attributes[:'transactionOrigin']
  end

  if attributes.has_key?(:'dynamicMerchantName')
    self.dynamic_merchant_name = attributes[:'dynamicMerchantName']
  end

  if attributes.has_key?(:'frequency')
    self.frequency = attributes[:'frequency']
  end

  if attributes.has_key?(:'transactionAmount')
    self.transaction_amount = attributes[:'transactionAmount']
  end

  if attributes.has_key?(:'clientLocale')
    self.client_locale = attributes[:'clientLocale']
  end

  if attributes.has_key?(:'orderId')
    self.order_id = attributes[:'orderId']
  end

  if attributes.has_key?(:'billing')
    self.billing = attributes[:'billing']
  end

  if attributes.has_key?(:'shipping')
    self.shipping = attributes[:'shipping']
  end

  if attributes.has_key?(:'comments')
    self.comments = attributes[:'comments']
  end
end

Instance Attribute Details

#billing ⇒ Object

Returns the value of attribute billing.



53
54
55
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 53

def billing
  @billing
end

#client_locale ⇒ Object

Returns the value of attribute client_locale.



48
49
50
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 48

def client_locale
  @client_locale
end

#comments ⇒ Object

User supplied comments.



58
59
60
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 58

def comments
  @comments
end

#dynamic_merchant_name ⇒ Object

Dynamic merchant name for the cardholder's statement.



42
43
44
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 42

def dynamic_merchant_name
  @dynamic_merchant_name
end

#frequency ⇒ Object

Returns the value of attribute frequency.



44
45
46
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 44

def frequency
  @frequency
end

#invoice_number ⇒ Object

Invoice number.



34
35
36
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 34

def invoice_number
  @invoice_number
end

#maximum_failures ⇒ Object

Number of failures that can be encountered before re-tries cease.



31
32
33
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 31

def maximum_failures
  @maximum_failures
end

#number_of_payments ⇒ Object

Number of times the recurring payment will process.



28
29
30
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 28

def number_of_payments
  @number_of_payments
end

#order_id ⇒ Object

Client order ID if supplied by client.



51
52
53
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 51

def order_id
  @order_id
end

#purchase_order_number ⇒ Object

Purchase order number.



37
38
39
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 37

def purchase_order_number
  @purchase_order_number
end

#request_type ⇒ Object

Object name of the payment schedules request.



19
20
21
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 19

def request_type
  @request_type
end

#shipping ⇒ Object

Returns the value of attribute shipping.



55
56
57
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 55

def shipping
  @shipping
end

#start_date ⇒ Object

Date of mandate signature.



25
26
27
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 25

def start_date
  @start_date
end

#store_id ⇒ Object

Store ID number.



22
23
24
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 22

def store_id
  @store_id
end

#transaction_amount ⇒ Object

Returns the value of attribute transaction_amount.



46
47
48
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 46

def transaction_amount
  @transaction_amount
end

#transaction_origin ⇒ Object

Returns the value of attribute transaction_origin.



39
40
41
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 39

def transaction_origin
  @transaction_origin
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 61

def self.attribute_map
  {
    :'request_type' => :'requestType',
    :'store_id' => :'storeId',
    :'start_date' => :'startDate',
    :'number_of_payments' => :'numberOfPayments',
    :'maximum_failures' => :'maximumFailures',
    :'invoice_number' => :'invoiceNumber',
    :'purchase_order_number' => :'purchaseOrderNumber',
    :'transaction_origin' => :'transactionOrigin',
    :'dynamic_merchant_name' => :'dynamicMerchantName',
    :'frequency' => :'frequency',
    :'transaction_amount' => :'transactionAmount',
    :'client_locale' => :'clientLocale',
    :'order_id' => :'orderId',
    :'billing' => :'billing',
    :'shipping' => :'shipping',
    :'comments' => :'comments'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 83

def self.openapi_types
  {
    :'request_type' => :'String',
    :'store_id' => :'String',
    :'start_date' => :'Date',
    :'number_of_payments' => :'Integer',
    :'maximum_failures' => :'Integer',
    :'invoice_number' => :'String',
    :'purchase_order_number' => :'String',
    :'transaction_origin' => :'TransactionOrigin',
    :'dynamic_merchant_name' => :'String',
    :'frequency' => :'Frequency',
    :'transaction_amount' => :'Amount',
    :'client_locale' => :'ClientLocale',
    :'order_id' => :'String',
    :'billing' => :'Billing',
    :'shipping' => :'Shipping',
    :'comments' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 275

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      request_type == o.request_type &&
      store_id == o.store_id &&
      start_date == o.start_date &&
      number_of_payments == o.number_of_payments &&
      maximum_failures == o.maximum_failures &&
      invoice_number == o.invoice_number &&
      purchase_order_number == o.purchase_order_number &&
      transaction_origin == o.transaction_origin &&
      dynamic_merchant_name == o.dynamic_merchant_name &&
      frequency == o.frequency &&
      transaction_amount == o.transaction_amount &&
      client_locale == o.client_locale &&
      order_id == o.order_id &&
      billing == o.billing &&
      shipping == o.shipping &&
      comments == o.comments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 332

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 311

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 298

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



304
305
306
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 304

def hash
  [request_type, store_id, start_date, number_of_payments, maximum_failures, invoice_number, purchase_order_number, transaction_origin, dynamic_merchant_name, frequency, transaction_amount, client_locale, order_id, billing, shipping, comments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  if @request_type.nil?
    invalid_properties.push('invalid value for "request_type", request_type cannot be nil.')
  end

  if !@store_id.nil? && @store_id.to_s.length > 20
    invalid_properties.push('invalid value for "store_id", the character length must be smaller than or equal to 20.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if !@number_of_payments.nil? && @number_of_payments > 999
    invalid_properties.push('invalid value for "number_of_payments", must be smaller than or equal to 999.')
  end

  if !@number_of_payments.nil? && @number_of_payments < 1
    invalid_properties.push('invalid value for "number_of_payments", must be greater than or equal to 1.')
  end

  if !@maximum_failures.nil? && @maximum_failures > 999
    invalid_properties.push('invalid value for "maximum_failures", must be smaller than or equal to 999.')
  end

  if !@maximum_failures.nil? && @maximum_failures < 1
    invalid_properties.push('invalid value for "maximum_failures", must be greater than or equal to 1.')
  end

  if @frequency.nil?
    invalid_properties.push('invalid value for "frequency", frequency cannot be nil.')
  end

  if @transaction_amount.nil?
    invalid_properties.push('invalid value for "transaction_amount", transaction_amount cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



378
379
380
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 378

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



372
373
374
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 372

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/openapi_client/models/payment_schedules_request.rb', line 222

def valid?
  return false if @request_type.nil?
  return false if !@store_id.nil? && @store_id.to_s.length > 20
  return false if @start_date.nil?
  return false if !@number_of_payments.nil? && @number_of_payments > 999
  return false if !@number_of_payments.nil? && @number_of_payments < 1
  return false if !@maximum_failures.nil? && @maximum_failures > 999
  return false if !@maximum_failures.nil? && @maximum_failures < 1
  return false if @frequency.nil?
  return false if @transaction_amount.nil?
  true
end