Class: OpenapiClient::PaymentTokenizationErrorResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/payment_tokenization_error_response.rb

Overview

Payment tokenization response with error field included.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentTokenizationErrorResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'clientRequestId')
    self.client_request_id = attributes[:'clientRequestId']
  end

  if attributes.has_key?(:'apiTraceId')
    self.api_trace_id = attributes[:'apiTraceId']
  end

  if attributes.has_key?(:'responseType')
    self.response_type = attributes[:'responseType']
  end

  if attributes.has_key?(:'requestStatus')
    self.request_status = attributes[:'requestStatus']
  end

  if attributes.has_key?(:'requestTime')
    self.request_time = attributes[:'requestTime']
  end

  if attributes.has_key?(:'avsResponse')
    self.avs_response = attributes[:'avsResponse']
  end

  if attributes.has_key?(:'securityCodeResponse')
    self.security_code_response = attributes[:'securityCodeResponse']
  end

  if attributes.has_key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'paymentToken')
    self.payment_token = attributes[:'paymentToken']
  end

  if attributes.has_key?(:'paymentCard')
    self.payment_card = attributes[:'paymentCard']
  end

  if attributes.has_key?(:'error')
    self.error = attributes[:'error']
  end
end

Instance Attribute Details

#api_trace_id ⇒ Object

Request identifier in API, can be used to request logs from the support team.



22
23
24
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 22

def api_trace_id
  @api_trace_id
end

#avs_response ⇒ Object

Returns the value of attribute avs_response.



32
33
34
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 32

def avs_response
  @avs_response
end

#brand ⇒ Object

Card brand.



38
39
40
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 38

def brand
  @brand
end

#client_request_id ⇒ Object

Echoes back the value in the request header for tracking.



19
20
21
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 19

def client_request_id
  @client_request_id
end

#country ⇒ Object

Country of the card issued.



41
42
43
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 41

def country
  @country
end

#error ⇒ Object

Returns the value of attribute error.



47
48
49
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 47

def error
  @error
end

#payment_card ⇒ Object

Returns the value of attribute payment_card.



45
46
47
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 45

def payment_card
  @payment_card
end

#payment_token ⇒ Object

Returns the value of attribute payment_token.



43
44
45
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 43

def payment_token
  @payment_token
end

#request_status ⇒ Object

The status of the request.



27
28
29
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 27

def request_status
  @request_status
end

#request_time ⇒ Object

Time of the request.



30
31
32
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 30

def request_time
  @request_time
end

#response_type ⇒ Object

Returns the value of attribute response_type.



24
25
26
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 24

def response_type
  @response_type
end

#security_code_response ⇒ Object

Security code check response.



35
36
37
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 35

def security_code_response
  @security_code_response
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 72

def self.attribute_map
  {
    :'client_request_id' => :'clientRequestId',
    :'api_trace_id' => :'apiTraceId',
    :'response_type' => :'responseType',
    :'request_status' => :'requestStatus',
    :'request_time' => :'requestTime',
    :'avs_response' => :'avsResponse',
    :'security_code_response' => :'securityCodeResponse',
    :'brand' => :'brand',
    :'country' => :'country',
    :'payment_token' => :'paymentToken',
    :'payment_card' => :'paymentCard',
    :'error' => :'error'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 90

def self.openapi_types
  {
    :'client_request_id' => :'String',
    :'api_trace_id' => :'String',
    :'response_type' => :'ResponseType',
    :'request_status' => :'String',
    :'request_time' => :'Integer',
    :'avs_response' => :'AVSResponse',
    :'security_code_response' => :'String',
    :'brand' => :'String',
    :'country' => :'String',
    :'payment_token' => :'PaymentTokenDetails',
    :'payment_card' => :'PaymentCard',
    :'error' => :'Error'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_request_id == o.client_request_id &&
      api_trace_id == o.api_trace_id &&
      response_type == o.response_type &&
      request_status == o.request_status &&
      request_time == o.request_time &&
      avs_response == o.avs_response &&
      security_code_response == o.security_code_response &&
      brand == o.brand &&
      country == o.country &&
      payment_token == o.payment_token &&
      payment_card == o.payment_card &&
      error == o.error
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 244

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 310

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 210

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



216
217
218
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 216

def hash
  [client_request_id, api_trace_id, response_type, request_status, request_time, avs_response, security_code_response, brand, country, payment_token, payment_card, error].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 166

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



290
291
292
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 290

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



284
285
286
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 284

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



173
174
175
176
177
# File 'lib/openapi_client/models/payment_tokenization_error_response.rb', line 173

def valid?
  request_status_validator = EnumAttributeValidator.new('String', ['DELETED', 'FAILED', 'SUCCESS', 'APPROVED', 'WAITING', 'VALIDATION_FAILED', 'DECLINED'])
  return false unless request_status_validator.valid?(@request_status)
  true
end