Class: OpenapiClient::ProcessorData
- Inherits:
-
Object
- Object
- OpenapiClient::ProcessorData
- Defined in:
- lib/openapi_client/models/processor_data.rb
Overview
Model for processor data.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#association_response_code ⇒ Object
Raw response code from issuer.
-
#authorization_code ⇒ Object
Code returned to confirm transaction.
-
#avs_response ⇒ Object
Returns the value of attribute avs_response.
-
#merchant_advice_code_indicator ⇒ Object
Code to map merchant advice code to ISO specification.
-
#network ⇒ Object
Network used for transaction.
-
#reference_number ⇒ Object
Reference transaction ID.
-
#response_code ⇒ Object
Response code from endpoints.
-
#response_message ⇒ Object
Message returned from endpoints.
-
#security_code_response ⇒ Object
Code returned for CVV.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProcessorData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProcessorData
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/openapi_client/models/processor_data.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'referenceNumber') self.reference_number = attributes[:'referenceNumber'] end if attributes.has_key?(:'authorizationCode') self. = attributes[:'authorizationCode'] end if attributes.has_key?(:'responseCode') self.response_code = attributes[:'responseCode'] end if attributes.has_key?(:'network') self.network = attributes[:'network'] end if attributes.has_key?(:'associationResponseCode') self.association_response_code = attributes[:'associationResponseCode'] end if attributes.has_key?(:'responseMessage') self. = attributes[:'responseMessage'] end if attributes.has_key?(:'avsResponse') self.avs_response = attributes[:'avsResponse'] end if attributes.has_key?(:'securityCodeResponse') self.security_code_response = attributes[:'securityCodeResponse'] end if attributes.has_key?(:'merchantAdviceCodeIndicator') self.merchant_advice_code_indicator = attributes[:'merchantAdviceCodeIndicator'] end end |
Instance Attribute Details
#association_response_code ⇒ Object
Raw response code from issuer.
31 32 33 |
# File 'lib/openapi_client/models/processor_data.rb', line 31 def association_response_code @association_response_code end |
#authorization_code ⇒ Object
Code returned to confirm transaction.
22 23 24 |
# File 'lib/openapi_client/models/processor_data.rb', line 22 def @authorization_code end |
#avs_response ⇒ Object
Returns the value of attribute avs_response.
36 37 38 |
# File 'lib/openapi_client/models/processor_data.rb', line 36 def avs_response @avs_response end |
#merchant_advice_code_indicator ⇒ Object
Code to map merchant advice code to ISO specification.
42 43 44 |
# File 'lib/openapi_client/models/processor_data.rb', line 42 def merchant_advice_code_indicator @merchant_advice_code_indicator end |
#network ⇒ Object
Network used for transaction.
28 29 30 |
# File 'lib/openapi_client/models/processor_data.rb', line 28 def network @network end |
#reference_number ⇒ Object
Reference transaction ID.
19 20 21 |
# File 'lib/openapi_client/models/processor_data.rb', line 19 def reference_number @reference_number end |
#response_code ⇒ Object
Response code from endpoints.
25 26 27 |
# File 'lib/openapi_client/models/processor_data.rb', line 25 def response_code @response_code end |
#response_message ⇒ Object
Message returned from endpoints.
34 35 36 |
# File 'lib/openapi_client/models/processor_data.rb', line 34 def @response_message end |
#security_code_response ⇒ Object
Code returned for CVV.
39 40 41 |
# File 'lib/openapi_client/models/processor_data.rb', line 39 def security_code_response @security_code_response end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/openapi_client/models/processor_data.rb', line 67 def self.attribute_map { :'reference_number' => :'referenceNumber', :'authorization_code' => :'authorizationCode', :'response_code' => :'responseCode', :'network' => :'network', :'association_response_code' => :'associationResponseCode', :'response_message' => :'responseMessage', :'avs_response' => :'avsResponse', :'security_code_response' => :'securityCodeResponse', :'merchant_advice_code_indicator' => :'merchantAdviceCodeIndicator' } end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/openapi_client/models/processor_data.rb', line 82 def self.openapi_types { :'reference_number' => :'String', :'authorization_code' => :'String', :'response_code' => :'String', :'network' => :'String', :'association_response_code' => :'String', :'response_message' => :'String', :'avs_response' => :'AVSResponse', :'security_code_response' => :'String', :'merchant_advice_code_indicator' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/openapi_client/models/processor_data.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && reference_number == o.reference_number && == o. && response_code == o.response_code && network == o.network && association_response_code == o.association_response_code && == o. && avs_response == o.avs_response && security_code_response == o.security_code_response && merchant_advice_code_indicator == o.merchant_advice_code_indicator end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/openapi_client/models/processor_data.rb', line 233 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/openapi_client/models/processor_data.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/openapi_client/models/processor_data.rb', line 212 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/openapi_client/models/processor_data.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/openapi_client/models/processor_data.rb', line 205 def hash [reference_number, , response_code, network, association_response_code, , avs_response, security_code_response, merchant_advice_code_indicator].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 |
# File 'lib/openapi_client/models/processor_data.rb', line 143 def list_invalid_properties invalid_properties = Array.new if !@merchant_advice_code_indicator.nil? && @merchant_advice_code_indicator !~ Regexp.new(/[0-9]{2}/) invalid_properties.push('invalid value for "merchant_advice_code_indicator", must conform to the pattern /[0-9]{2}/.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
279 280 281 |
# File 'lib/openapi_client/models/processor_data.rb', line 279 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 |
# File 'lib/openapi_client/models/processor_data.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/openapi_client/models/processor_data.rb', line 273 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 158 159 |
# File 'lib/openapi_client/models/processor_data.rb', line 154 def valid? security_code_response_validator = EnumAttributeValidator.new('String', ['MATCHED', 'NOT_MATCHED', 'NOT_PROCESSED', 'NOT_PRESENT', 'NOT_CERTIFIED']) return false unless security_code_response_validator.valid?(@security_code_response) return false if !@merchant_advice_code_indicator.nil? && @merchant_advice_code_indicator !~ Regexp.new(/[0-9]{2}/) true end |