Class: OpenapiClient::ScoreOnlyRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/models/score_only_request.rb

Overview

Fraud detect request payload.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ScoreOnlyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/openapi_client/models/score_only_request.rb', line 117

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'merchantRef')
    self.merchant_ref = attributes[:'merchantRef']
  end

  if attributes.has_key?(:'transactionType')
    self.transaction_type = attributes[:'transactionType']
  end

  if attributes.has_key?(:'originalTransactionType')
    self.original_transaction_type = attributes[:'originalTransactionType']
  end

  if attributes.has_key?(:'originalTransactionId')
    self.original_transaction_id = attributes[:'originalTransactionId']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'currencyCode')
    self.currency_code = attributes[:'currencyCode']
  end

  if attributes.has_key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.has_key?(:'billingAddress')
    self.billing_address = attributes[:'billingAddress']
  end

  if attributes.has_key?(:'device')
    self.device = attributes[:'device']
  end

  if attributes.has_key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.has_key?(:'payment')
    self.payment = attributes[:'payment']
  end

  if attributes.has_key?(:'merchant')
    self.merchant = attributes[:'merchant']
  end

  if attributes.has_key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.has_key?(:'userDefined')
    self.user_defined = attributes[:'userDefined']
  end
end

Instance Attribute Details

#amount ⇒ Object

The amount processed for the original transaction.



31
32
33
# File 'lib/openapi_client/models/score_only_request.rb', line 31

def amount
  @amount
end

#billing_address ⇒ Object

Returns the value of attribute billing_address.



38
39
40
# File 'lib/openapi_client/models/score_only_request.rb', line 38

def billing_address
  @billing_address
end

#currency_code ⇒ Object

The currency of the original transaction.



34
35
36
# File 'lib/openapi_client/models/score_only_request.rb', line 34

def currency_code
  @currency_code
end

#customer ⇒ Object

Returns the value of attribute customer.



36
37
38
# File 'lib/openapi_client/models/score_only_request.rb', line 36

def customer
  @customer
end

#device ⇒ Object

Returns the value of attribute device.



40
41
42
# File 'lib/openapi_client/models/score_only_request.rb', line 40

def device
  @device
end

#loyalty ⇒ Object

Returns the value of attribute loyalty.



42
43
44
# File 'lib/openapi_client/models/score_only_request.rb', line 42

def loyalty
  @loyalty
end

#merchant ⇒ Object

Returns the value of attribute merchant.



46
47
48
# File 'lib/openapi_client/models/score_only_request.rb', line 46

def merchant
  @merchant
end

#merchant_ref ⇒ Object

Merchant reference code. Used by FirstAPI and reflected in settlement records and Webhook notifications. Typically, the merchantRef field is the purchase order number or unique sequence value associated to a given transaction.



19
20
21
# File 'lib/openapi_client/models/score_only_request.rb', line 19

def merchant_ref
  @merchant_ref
end

#order ⇒ Object

Returns the value of attribute order.



48
49
50
# File 'lib/openapi_client/models/score_only_request.rb', line 48

def order
  @order
end

#original_transaction_id ⇒ Object

The unique ID of this transaction. Must be unique for the entire system (not just within a specific merchant or industry). Subsequent requests related to the same transaction must have the same transactionId (e.g. transaction/deposit or transaction/authorization-reversal). This field is used for matching transactions with settlement and chargeback information. If there is no such ID available you may wish to compose one from fields available in both systems. Consider including backend, issuer, merchant id, date and time, amount, etc. as necessary.



28
29
30
# File 'lib/openapi_client/models/score_only_request.rb', line 28

def original_transaction_id
  @original_transaction_id
end

#original_transaction_type ⇒ Object

Defines the type of the original transaction that is being evaluated for the Fraud Score.



25
26
27
# File 'lib/openapi_client/models/score_only_request.rb', line 25

def original_transaction_type
  @original_transaction_type
end

#payment ⇒ Object

Returns the value of attribute payment.



44
45
46
# File 'lib/openapi_client/models/score_only_request.rb', line 44

def payment
  @payment
end

#transaction_type ⇒ Object

Type of transaction merchant wants to process.



22
23
24
# File 'lib/openapi_client/models/score_only_request.rb', line 22

def transaction_type
  @transaction_type
end

#user_defined ⇒ Object

A JSON object that can carry any additional information that might be helpful for fraud detection.



51
52
53
# File 'lib/openapi_client/models/score_only_request.rb', line 51

def user_defined
  @user_defined
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/openapi_client/models/score_only_request.rb', line 76

def self.attribute_map
  {
    :'merchant_ref' => :'merchantRef',
    :'transaction_type' => :'transactionType',
    :'original_transaction_type' => :'originalTransactionType',
    :'original_transaction_id' => :'originalTransactionId',
    :'amount' => :'amount',
    :'currency_code' => :'currencyCode',
    :'customer' => :'customer',
    :'billing_address' => :'billingAddress',
    :'device' => :'device',
    :'loyalty' => :'loyalty',
    :'payment' => :'payment',
    :'merchant' => :'merchant',
    :'order' => :'order',
    :'user_defined' => :'userDefined'
  }
end

.openapi_types ⇒ Object

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/openapi_client/models/score_only_request.rb', line 96

def self.openapi_types
  {
    :'merchant_ref' => :'String',
    :'transaction_type' => :'String',
    :'original_transaction_type' => :'String',
    :'original_transaction_id' => :'String',
    :'amount' => :'String',
    :'currency_code' => :'String',
    :'customer' => :'Customer',
    :'billing_address' => :'BillingAddress',
    :'device' => :'Device',
    :'loyalty' => :'Loyalty',
    :'payment' => :'Payment',
    :'merchant' => :'Merchant',
    :'order' => :'FraudOrder',
    :'user_defined' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/openapi_client/models/score_only_request.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      merchant_ref == o.merchant_ref &&
      transaction_type == o.transaction_type &&
      original_transaction_type == o.original_transaction_type &&
      original_transaction_id == o.original_transaction_id &&
      amount == o.amount &&
      currency_code == o.currency_code &&
      customer == o.customer &&
      billing_address == o.billing_address &&
      device == o.device &&
      loyalty == o.loyalty &&
      payment == o.payment &&
      merchant == o.merchant &&
      order == o.order &&
      user_defined == o.user_defined
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/openapi_client/models/score_only_request.rb', line 309

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = OpenapiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/openapi_client/models/score_only_request.rb', line 375

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/openapi_client/models/score_only_request.rb', line 288

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/openapi_client/models/score_only_request.rb', line 275

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



281
282
283
# File 'lib/openapi_client/models/score_only_request.rb', line 281

def hash
  [merchant_ref, transaction_type, original_transaction_type, original_transaction_id, amount, currency_code, customer, billing_address, device, loyalty, payment, merchant, order, user_defined].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/openapi_client/models/score_only_request.rb', line 182

def list_invalid_properties
  invalid_properties = Array.new
  if @transaction_type.nil?
    invalid_properties.push('invalid value for "transaction_type", transaction_type cannot be nil.')
  end

  if @original_transaction_type.nil?
    invalid_properties.push('invalid value for "original_transaction_type", original_transaction_type cannot be nil.')
  end

  if @original_transaction_id.nil?
    invalid_properties.push('invalid value for "original_transaction_id", original_transaction_id cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @currency_code.nil?
    invalid_properties.push('invalid value for "currency_code", currency_code cannot be nil.')
  end

  if @payment.nil?
    invalid_properties.push('invalid value for "payment", payment cannot be nil.')
  end

  if @merchant.nil?
    invalid_properties.push('invalid value for "merchant", merchant cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



355
356
357
# File 'lib/openapi_client/models/score_only_request.rb', line 355

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
# File 'lib/openapi_client/models/score_only_request.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



349
350
351
# File 'lib/openapi_client/models/score_only_request.rb', line 349

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/openapi_client/models/score_only_request.rb', line 217

def valid?
  return false if @transaction_type.nil?
  transaction_type_validator = EnumAttributeValidator.new('String', ['scoreOnly'])
  return false unless transaction_type_validator.valid?(@transaction_type)
  return false if @original_transaction_type.nil?
  original_transaction_type_validator = EnumAttributeValidator.new('String', ['transaction/authorization', 'transaction/authorization-reversal', 'transaction/deposit', 'transaction/deposit-reversal', 'transaction/purchase', 'transaction/purchase-reversal', 'transaction/refund-authorization', 'transaction/refund-deposit', 'transaction/verification', 'transaction/balance-inquiry'])
  return false unless original_transaction_type_validator.valid?(@original_transaction_type)
  return false if @original_transaction_id.nil?
  return false if @amount.nil?
  return false if @currency_code.nil?
  return false if @payment.nil?
  return false if @merchant.nil?
  true
end