Class: OpenapiClient::Sepa
- Inherits:
-
Object
- Object
- OpenapiClient::Sepa
- Defined in:
- lib/openapi_client/models/sepa.rb
Overview
The payment object for SEPA Local Payment.
Instance Attribute Summary collapse
-
#country ⇒ Object
Country of residence of the payer using the ISO 3166 standard.
-
#email ⇒ Object
The email address of the payer.
-
#iban ⇒ Object
Bank account in IBAN format.
-
#mandate ⇒ Object
Returns the value of attribute mandate.
-
#name ⇒ Object
The name of the payer.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Sepa
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Sepa
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/openapi_client/models/sepa.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'iban') self.iban = attributes[:'iban'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'country') self.country = attributes[:'country'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'mandate') self.mandate = attributes[:'mandate'] end end |
Instance Attribute Details
#country ⇒ Object
Country of residence of the payer using the ISO 3166 standard.
25 26 27 |
# File 'lib/openapi_client/models/sepa.rb', line 25 def country @country end |
#email ⇒ Object
The email address of the payer.
28 29 30 |
# File 'lib/openapi_client/models/sepa.rb', line 28 def email @email end |
#iban ⇒ Object
Bank account in IBAN format.
19 20 21 |
# File 'lib/openapi_client/models/sepa.rb', line 19 def iban @iban end |
#mandate ⇒ Object
Returns the value of attribute mandate.
30 31 32 |
# File 'lib/openapi_client/models/sepa.rb', line 30 def mandate @mandate end |
#name ⇒ Object
The name of the payer.
22 23 24 |
# File 'lib/openapi_client/models/sepa.rb', line 22 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/openapi_client/models/sepa.rb', line 33 def self.attribute_map { :'iban' => :'iban', :'name' => :'name', :'country' => :'country', :'email' => :'email', :'mandate' => :'mandate' } end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 |
# File 'lib/openapi_client/models/sepa.rb', line 44 def self.openapi_types { :'iban' => :'String', :'name' => :'String', :'country' => :'String', :'email' => :'String', :'mandate' => :'SepaMandate' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 |
# File 'lib/openapi_client/models/sepa.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && iban == o.iban && name == o.name && country == o.country && email == o.email && mandate == o.mandate end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/openapi_client/models/sepa.rb', line 236 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/openapi_client/models/sepa.rb', line 302 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/openapi_client/models/sepa.rb', line 215 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/openapi_client/models/sepa.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/openapi_client/models/sepa.rb', line 208 def hash [iban, name, country, email, mandate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/openapi_client/models/sepa.rb', line 85 def list_invalid_properties invalid_properties = Array.new if @iban.nil? invalid_properties.push('invalid value for "iban", iban cannot be nil.') end if @iban.to_s.length > 34 invalid_properties.push('invalid value for "iban", the character length must be smaller than or equal to 34.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 96 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 96.') end if @country.nil? invalid_properties.push('invalid value for "country", country cannot be nil.') end if @country.to_s.length > 3 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 3.') end if !@email.nil? && @email.to_s.length > 254 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.') end if @mandate.nil? invalid_properties.push('invalid value for "mandate", mandate cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
282 283 284 |
# File 'lib/openapi_client/models/sepa.rb', line 282 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 |
# File 'lib/openapi_client/models/sepa.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
276 277 278 |
# File 'lib/openapi_client/models/sepa.rb', line 276 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/openapi_client/models/sepa.rb', line 124 def valid? return false if @iban.nil? return false if @iban.to_s.length > 34 return false if @name.nil? return false if @name.to_s.length > 96 return false if @country.nil? return false if @country.to_s.length > 3 return false if !@email.nil? && @email.to_s.length > 254 return false if @mandate.nil? true end |