Class: OpenapiClient::AliPay
- Inherits:
-
Object
- Object
- OpenapiClient::AliPay
- Defined in:
- lib/openapi_client/models/ali_pay.rb
Overview
The payment object for AliPay transactions. Use this to populate Alipay payment method details.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#order_details ⇒ Object
Use this to send order details that show up in the statement.
-
#order_title ⇒ Object
Use this to send an order title that shows up in the statement.
-
#payment_data ⇒ Object
Use this to send payment related information, such as customer identity ID.
-
#payment_data_type ⇒ Object
Use this to indicate the type of machine-readable payment data for scanning.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AliPay
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AliPay
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/openapi_client/models/ali_pay.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'paymentDataType') self.payment_data_type = attributes[:'paymentDataType'] end if attributes.has_key?(:'paymentData') self.payment_data = attributes[:'paymentData'] end if attributes.has_key?(:'orderTitle') self.order_title = attributes[:'orderTitle'] end if attributes.has_key?(:'orderDetails') self.order_details = attributes[:'orderDetails'] end end |
Instance Attribute Details
#order_details ⇒ Object
Use this to send order details that show up in the statement.
28 29 30 |
# File 'lib/openapi_client/models/ali_pay.rb', line 28 def order_details @order_details end |
#order_title ⇒ Object
Use this to send an order title that shows up in the statement.
25 26 27 |
# File 'lib/openapi_client/models/ali_pay.rb', line 25 def order_title @order_title end |
#payment_data ⇒ Object
Use this to send payment related information, such as customer identity ID.
22 23 24 |
# File 'lib/openapi_client/models/ali_pay.rb', line 22 def payment_data @payment_data end |
#payment_data_type ⇒ Object
Use this to indicate the type of machine-readable payment data for scanning.
19 20 21 |
# File 'lib/openapi_client/models/ali_pay.rb', line 19 def payment_data_type @payment_data_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/openapi_client/models/ali_pay.rb', line 53 def self.attribute_map { :'payment_data_type' => :'paymentDataType', :'payment_data' => :'paymentData', :'order_title' => :'orderTitle', :'order_details' => :'orderDetails' } end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 |
# File 'lib/openapi_client/models/ali_pay.rb', line 63 def self.openapi_types { :'payment_data_type' => :'String', :'payment_data' => :'String', :'order_title' => :'String', :'order_details' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 208 |
# File 'lib/openapi_client/models/ali_pay.rb', line 201 def ==(o) return true if self.equal?(o) self.class == o.class && payment_data_type == o.payment_data_type && payment_data == o.payment_data && order_title == o.order_title && order_details == o.order_details end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/openapi_client/models/ali_pay.rb', line 246 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/openapi_client/models/ali_pay.rb', line 312 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/openapi_client/models/ali_pay.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/openapi_client/models/ali_pay.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/openapi_client/models/ali_pay.rb', line 218 def hash [payment_data_type, payment_data, order_title, order_details].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/openapi_client/models/ali_pay.rb', line 99 def list_invalid_properties invalid_properties = Array.new if @payment_data_type.nil? invalid_properties.push('invalid value for "payment_data_type", payment_data_type cannot be nil.') end if @payment_data.nil? invalid_properties.push('invalid value for "payment_data", payment_data cannot be nil.') end if @payment_data.to_s.length > 100 invalid_properties.push('invalid value for "payment_data", the character length must be smaller than or equal to 100.') end if @order_title.nil? invalid_properties.push('invalid value for "order_title", order_title cannot be nil.') end if @order_title.to_s.length > 100 invalid_properties.push('invalid value for "order_title", the character length must be smaller than or equal to 100.') end if @order_details.nil? invalid_properties.push('invalid value for "order_details", order_details cannot be nil.') end if @order_details.to_s.length > 1024 invalid_properties.push('invalid value for "order_details", the character length must be smaller than or equal to 1024.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
292 293 294 |
# File 'lib/openapi_client/models/ali_pay.rb', line 292 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 |
# File 'lib/openapi_client/models/ali_pay.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/openapi_client/models/ali_pay.rb', line 286 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/openapi_client/models/ali_pay.rb', line 134 def valid? return false if @payment_data_type.nil? payment_data_type_validator = EnumAttributeValidator.new('String', ['BARCODE', 'QRCODE']) return false unless payment_data_type_validator.valid?(@payment_data_type) return false if @payment_data.nil? return false if @payment_data.to_s.length > 100 return false if @order_title.nil? return false if @order_title.to_s.length > 100 return false if @order_details.nil? return false if @order_details.to_s.length > 1024 true end |