Class: OpenapiClient::ChinaDomestic
- Inherits:
-
Object
- Object
- OpenapiClient::ChinaDomestic
- Defined in:
- lib/openapi_client/models/china_domestic.rb
Overview
The payment object for China-domestic transactions. Use this to populate all china domestic payment method details.
Instance Attribute Summary collapse
-
#bank_id ⇒ Object
Use this to indicate the CUP bank ID if known.
-
#customer_id ⇒ Object
Use this to indicate the CUP customer ID if known.
-
#limit_card_function_to_debit ⇒ Object
Use this to limit card functions to debit cards.
-
#product_code ⇒ Object
Use this to indicate the product code according to the product category list.
-
#product_description ⇒ Object
The product description.
-
#product_price ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
-
#product_quantity ⇒ Object
The quantity.
-
#redirect_url ⇒ Object
Use this to indicate the product code according to the product category list.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChinaDomestic
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ChinaDomestic
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/openapi_client/models/china_domestic.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'productCode') self.product_code = attributes[:'productCode'] end if attributes.has_key?(:'productQuantity') self.product_quantity = attributes[:'productQuantity'] end if attributes.has_key?(:'productPrice') self.product_price = attributes[:'productPrice'] end if attributes.has_key?(:'productDescription') self.product_description = attributes[:'productDescription'] end if attributes.has_key?(:'redirectURL') self.redirect_url = attributes[:'redirectURL'] end if attributes.has_key?(:'limitCardFunctionToDebit') self.limit_card_function_to_debit = attributes[:'limitCardFunctionToDebit'] end if attributes.has_key?(:'customerId') self.customer_id = attributes[:'customerId'] end if attributes.has_key?(:'bankId') self.bank_id = attributes[:'bankId'] end end |
Instance Attribute Details
#bank_id ⇒ Object
Use this to indicate the CUP bank ID if known.
40 41 42 |
# File 'lib/openapi_client/models/china_domestic.rb', line 40 def bank_id @bank_id end |
#customer_id ⇒ Object
Use this to indicate the CUP customer ID if known.
37 38 39 |
# File 'lib/openapi_client/models/china_domestic.rb', line 37 def customer_id @customer_id end |
#limit_card_function_to_debit ⇒ Object
Use this to limit card functions to debit cards.
34 35 36 |
# File 'lib/openapi_client/models/china_domestic.rb', line 34 def limit_card_function_to_debit @limit_card_function_to_debit end |
#product_code ⇒ Object
Use this to indicate the product code according to the product category list.
19 20 21 |
# File 'lib/openapi_client/models/china_domestic.rb', line 19 def product_code @product_code end |
#product_description ⇒ Object
The product description.
28 29 30 |
# File 'lib/openapi_client/models/china_domestic.rb', line 28 def product_description @product_description end |
#product_price ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
25 26 27 |
# File 'lib/openapi_client/models/china_domestic.rb', line 25 def product_price @product_price end |
#product_quantity ⇒ Object
The quantity.
22 23 24 |
# File 'lib/openapi_client/models/china_domestic.rb', line 22 def product_quantity @product_quantity end |
#redirect_url ⇒ Object
Use this to indicate the product code according to the product category list.
31 32 33 |
# File 'lib/openapi_client/models/china_domestic.rb', line 31 def redirect_url @redirect_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/openapi_client/models/china_domestic.rb', line 43 def self.attribute_map { :'product_code' => :'productCode', :'product_quantity' => :'productQuantity', :'product_price' => :'productPrice', :'product_description' => :'productDescription', :'redirect_url' => :'redirectURL', :'limit_card_function_to_debit' => :'limitCardFunctionToDebit', :'customer_id' => :'customerId', :'bank_id' => :'bankId' } end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/openapi_client/models/china_domestic.rb', line 57 def self.openapi_types { :'product_code' => :'String', :'product_quantity' => :'Integer', :'product_price' => :'Float', :'product_description' => :'String', :'redirect_url' => :'String', :'limit_card_function_to_debit' => :'BOOLEAN', :'customer_id' => :'String', :'bank_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/openapi_client/models/china_domestic.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && product_code == o.product_code && product_quantity == o.product_quantity && product_price == o.product_price && product_description == o.product_description && redirect_url == o.redirect_url && limit_card_function_to_debit == o.limit_card_function_to_debit && customer_id == o.customer_id && bank_id == o.bank_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/openapi_client/models/china_domestic.rb', line 306 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/openapi_client/models/china_domestic.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/openapi_client/models/china_domestic.rb', line 285 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
272 273 274 |
# File 'lib/openapi_client/models/china_domestic.rb', line 272 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
278 279 280 |
# File 'lib/openapi_client/models/china_domestic.rb', line 278 def hash [product_code, product_quantity, product_price, product_description, redirect_url, limit_card_function_to_debit, customer_id, bank_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/openapi_client/models/china_domestic.rb', line 113 def list_invalid_properties invalid_properties = Array.new if @product_code.nil? invalid_properties.push('invalid value for "product_code", product_code cannot be nil.') end if @product_code.to_s.length > 32 invalid_properties.push('invalid value for "product_code", the character length must be smaller than or equal to 32.') end if @product_quantity.nil? invalid_properties.push('invalid value for "product_quantity", product_quantity cannot be nil.') end if @product_quantity < 1 invalid_properties.push('invalid value for "product_quantity", must be greater than or equal to 1.') end if @product_price.nil? invalid_properties.push('invalid value for "product_price", product_price cannot be nil.') end if @product_description.nil? invalid_properties.push('invalid value for "product_description", product_description cannot be nil.') end if @product_description.to_s.length > 100 invalid_properties.push('invalid value for "product_description", the character length must be smaller than or equal to 100.') end if @redirect_url.nil? invalid_properties.push('invalid value for "redirect_url", redirect_url cannot be nil.') end if @redirect_url.to_s.length > 1024 invalid_properties.push('invalid value for "redirect_url", the character length must be smaller than or equal to 1024.') end if !@customer_id.nil? && @customer_id.to_s.length > 32 invalid_properties.push('invalid value for "customer_id", the character length must be smaller than or equal to 32.') end if !@bank_id.nil? && @bank_id.to_s.length > 8 invalid_properties.push('invalid value for "bank_id", the character length must be smaller than or equal to 8.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
352 353 354 |
# File 'lib/openapi_client/models/china_domestic.rb', line 352 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 |
# File 'lib/openapi_client/models/china_domestic.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/openapi_client/models/china_domestic.rb', line 346 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/openapi_client/models/china_domestic.rb', line 164 def valid? return false if @product_code.nil? return false if @product_code.to_s.length > 32 return false if @product_quantity.nil? return false if @product_quantity < 1 return false if @product_price.nil? return false if @product_description.nil? return false if @product_description.to_s.length > 100 return false if @redirect_url.nil? return false if @redirect_url.to_s.length > 1024 return false if !@customer_id.nil? && @customer_id.to_s.length > 32 return false if !@bank_id.nil? && @bank_id.to_s.length > 8 true end |