Class: OpenapiClient::PaymentUrlRequest
- Inherits:
-
Object
- Object
- OpenapiClient::PaymentUrlRequest
- Defined in:
- lib/openapi_client/models/payment_url_request.rb
Overview
Request to generate an embedded payment link.
Instance Attribute Summary collapse
-
#authenticate_transaction ⇒ Object
If 3D secure should be applied.
-
#billing ⇒ Object
Returns the value of attribute billing.
-
#client_locale ⇒ Object
Returns the value of attribute client_locale.
-
#dynamic_merchant_name ⇒ Object
Dynamic merchant name for the cardholder's statement.
-
#expiration ⇒ Object
Time until payment URL expires.
-
#invoice_number ⇒ Object
Invoice number.
-
#ip ⇒ Object
IPv4 or IPv6 network address.
-
#order_id ⇒ Object
Client order ID if supplied by client, otherwise the order ID.
-
#purchase_order_number ⇒ Object
Purchase order number.
-
#shipping ⇒ Object
Returns the value of attribute shipping.
-
#store_id ⇒ Object
An optional Outlet ID for clients that support multiple stores in the same developer app.
-
#transaction_amount ⇒ Object
Returns the value of attribute transaction_amount.
-
#transaction_notification_url ⇒ Object
URL for notifying merchant of payment result.
-
#transaction_type ⇒ Object
Returns the value of attribute transaction_type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentUrlRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentUrlRequest
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'storeId') self.store_id = attributes[:'storeId'] end if attributes.has_key?(:'clientLocale') self.client_locale = attributes[:'clientLocale'] end if attributes.has_key?(:'transactionAmount') self.transaction_amount = attributes[:'transactionAmount'] end if attributes.has_key?(:'transactionType') self.transaction_type = attributes[:'transactionType'] end if attributes.has_key?(:'orderId') self.order_id = attributes[:'orderId'] end if attributes.has_key?(:'billing') self.billing = attributes[:'billing'] end if attributes.has_key?(:'shipping') self.shipping = attributes[:'shipping'] end if attributes.has_key?(:'transactionNotificationURL') self.transaction_notification_url = attributes[:'transactionNotificationURL'] end if attributes.has_key?(:'expiration') self.expiration = attributes[:'expiration'] end if attributes.has_key?(:'authenticateTransaction') self.authenticate_transaction = attributes[:'authenticateTransaction'] end if attributes.has_key?(:'dynamicMerchantName') self.dynamic_merchant_name = attributes[:'dynamicMerchantName'] end if attributes.has_key?(:'invoiceNumber') self.invoice_number = attributes[:'invoiceNumber'] end if attributes.has_key?(:'purchaseOrderNumber') self.purchase_order_number = attributes[:'purchaseOrderNumber'] end if attributes.has_key?(:'ip') self.ip = attributes[:'ip'] end end |
Instance Attribute Details
#authenticate_transaction ⇒ Object
If 3D secure should be applied.
41 42 43 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 41 def authenticate_transaction @authenticate_transaction end |
#billing ⇒ Object
Returns the value of attribute billing.
30 31 32 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 30 def billing @billing end |
#client_locale ⇒ Object
Returns the value of attribute client_locale.
21 22 23 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 21 def client_locale @client_locale end |
#dynamic_merchant_name ⇒ Object
Dynamic merchant name for the cardholder's statement.
44 45 46 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 44 def dynamic_merchant_name @dynamic_merchant_name end |
#expiration ⇒ Object
Time until payment URL expires.
38 39 40 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 38 def expiration @expiration end |
#invoice_number ⇒ Object
Invoice number.
47 48 49 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 47 def invoice_number @invoice_number end |
#ip ⇒ Object
IPv4 or IPv6 network address.
53 54 55 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 53 def ip @ip end |
#order_id ⇒ Object
Client order ID if supplied by client, otherwise the order ID.
28 29 30 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 28 def order_id @order_id end |
#purchase_order_number ⇒ Object
Purchase order number.
50 51 52 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 50 def purchase_order_number @purchase_order_number end |
#shipping ⇒ Object
Returns the value of attribute shipping.
32 33 34 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 32 def shipping @shipping end |
#store_id ⇒ Object
An optional Outlet ID for clients that support multiple stores in the same developer app.
19 20 21 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 19 def store_id @store_id end |
#transaction_amount ⇒ Object
Returns the value of attribute transaction_amount.
23 24 25 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 23 def transaction_amount @transaction_amount end |
#transaction_notification_url ⇒ Object
URL for notifying merchant of payment result.
35 36 37 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 35 def transaction_notification_url @transaction_notification_url end |
#transaction_type ⇒ Object
Returns the value of attribute transaction_type.
25 26 27 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 25 def transaction_type @transaction_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 56 def self.attribute_map { :'store_id' => :'storeId', :'client_locale' => :'clientLocale', :'transaction_amount' => :'transactionAmount', :'transaction_type' => :'transactionType', :'order_id' => :'orderId', :'billing' => :'billing', :'shipping' => :'shipping', :'transaction_notification_url' => :'transactionNotificationURL', :'expiration' => :'expiration', :'authenticate_transaction' => :'authenticateTransaction', :'dynamic_merchant_name' => :'dynamicMerchantName', :'invoice_number' => :'invoiceNumber', :'purchase_order_number' => :'purchaseOrderNumber', :'ip' => :'ip' } end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 76 def self.openapi_types { :'store_id' => :'String', :'client_locale' => :'ClientLocale', :'transaction_amount' => :'Amount', :'transaction_type' => :'TransactionType', :'order_id' => :'String', :'billing' => :'Billing', :'shipping' => :'Shipping', :'transaction_notification_url' => :'String', :'expiration' => :'Integer', :'authenticate_transaction' => :'BOOLEAN', :'dynamic_merchant_name' => :'String', :'invoice_number' => :'String', :'purchase_order_number' => :'String', :'ip' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && store_id == o.store_id && client_locale == o.client_locale && transaction_amount == o.transaction_amount && transaction_type == o.transaction_type && order_id == o.order_id && billing == o.billing && shipping == o.shipping && transaction_notification_url == o.transaction_notification_url && expiration == o.expiration && authenticate_transaction == o.authenticate_transaction && dynamic_merchant_name == o.dynamic_merchant_name && invoice_number == o.invoice_number && purchase_order_number == o.purchase_order_number && ip == o.ip end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 250 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 316 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 229 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 222 def hash [store_id, client_locale, transaction_amount, transaction_type, order_id, billing, shipping, transaction_notification_url, expiration, authenticate_transaction, dynamic_merchant_name, invoice_number, purchase_order_number, ip].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 162 def list_invalid_properties invalid_properties = Array.new if !@store_id.nil? && @store_id.to_s.length > 20 invalid_properties.push('invalid value for "store_id", the character length must be smaller than or equal to 20.') end if @transaction_type.nil? invalid_properties.push('invalid value for "transaction_type", transaction_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
296 297 298 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 296 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 290 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 |
# File 'lib/openapi_client/models/payment_url_request.rb', line 177 def valid? return false if !@store_id.nil? && @store_id.to_s.length > 20 return false if @transaction_type.nil? true end |