Class: OpenapiClient::PurchaseCardsLevel3LineItems
- Inherits:
-
Object
- Object
- OpenapiClient::PurchaseCardsLevel3LineItems
- Defined in:
- lib/openapi_client/models/purchase_cards_level3_line_items.rb
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
The commodity code used to classify the item purchased.
-
#description ⇒ Object
The description.
-
#discount_amount_and_rate ⇒ Object
Returns the value of attribute discount_amount_and_rate.
-
#line_item_total ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
-
#product_code ⇒ Object
Merchant product identifier/the Universal Product Code (UPC) of the item purchased.
-
#quantity ⇒ Object
The quantity.
-
#unit_measure ⇒ Object
The unit of measure.
-
#unit_price ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
-
#vat_amount_and_rate ⇒ Object
Returns the value of attribute vat_amount_and_rate.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PurchaseCardsLevel3LineItems
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PurchaseCardsLevel3LineItems
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'commodityCode') self.commodity_code = attributes[:'commodityCode'] end if attributes.has_key?(:'productCode') self.product_code = attributes[:'productCode'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.has_key?(:'unitMeasure') self.unit_measure = attributes[:'unitMeasure'] end if attributes.has_key?(:'unitPrice') self.unit_price = attributes[:'unitPrice'] end if attributes.has_key?(:'vatAmountAndRate') self.vat_amount_and_rate = attributes[:'vatAmountAndRate'] end if attributes.has_key?(:'discountAmountAndRate') self.discount_amount_and_rate = attributes[:'discountAmountAndRate'] end if attributes.has_key?(:'lineItemTotal') self.line_item_total = attributes[:'lineItemTotal'] end end |
Instance Attribute Details
#commodity_code ⇒ Object
The commodity code used to classify the item purchased.
18 19 20 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 18 def commodity_code @commodity_code end |
#description ⇒ Object
The description.
24 25 26 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 24 def description @description end |
#discount_amount_and_rate ⇒ Object
Returns the value of attribute discount_amount_and_rate.
37 38 39 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 37 def discount_amount_and_rate @discount_amount_and_rate end |
#line_item_total ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
40 41 42 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 40 def line_item_total @line_item_total end |
#product_code ⇒ Object
Merchant product identifier/the Universal Product Code (UPC) of the item purchased.
21 22 23 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 21 def product_code @product_code end |
#quantity ⇒ Object
The quantity.
27 28 29 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 27 def quantity @quantity end |
#unit_measure ⇒ Object
The unit of measure.
30 31 32 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 30 def unit_measure @unit_measure end |
#unit_price ⇒ Object
Rate amount in 3 decimal 12 bytes total digit.
33 34 35 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 33 def unit_price @unit_price end |
#vat_amount_and_rate ⇒ Object
Returns the value of attribute vat_amount_and_rate.
35 36 37 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 35 def vat_amount_and_rate @vat_amount_and_rate end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 43 def self.attribute_map { :'commodity_code' => :'commodityCode', :'product_code' => :'productCode', :'description' => :'description', :'quantity' => :'quantity', :'unit_measure' => :'unitMeasure', :'unit_price' => :'unitPrice', :'vat_amount_and_rate' => :'vatAmountAndRate', :'discount_amount_and_rate' => :'discountAmountAndRate', :'line_item_total' => :'lineItemTotal' } end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 58 def self.openapi_types { :'commodity_code' => :'String', :'product_code' => :'String', :'description' => :'String', :'quantity' => :'Integer', :'unit_measure' => :'String', :'unit_price' => :'Float', :'vat_amount_and_rate' => :'AdditionalAmountRate', :'discount_amount_and_rate' => :'AdditionalAmountRate', :'line_item_total' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && commodity_code == o.commodity_code && product_code == o.product_code && description == o.description && quantity == o.quantity && unit_measure == o.unit_measure && unit_price == o.unit_price && vat_amount_and_rate == o.vat_amount_and_rate && discount_amount_and_rate == o.discount_amount_and_rate && line_item_total == o.line_item_total end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 257 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = OpenapiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 236 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 229 def hash [commodity_code, product_code, description, quantity, unit_measure, unit_price, vat_amount_and_rate, discount_amount_and_rate, line_item_total].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 119 def list_invalid_properties invalid_properties = Array.new if !@commodity_code.nil? && @commodity_code.to_s.length > 4 invalid_properties.push('invalid value for "commodity_code", the character length must be smaller than or equal to 4.') end if !@product_code.nil? && @product_code.to_s.length > 20 invalid_properties.push('invalid value for "product_code", the character length must be smaller than or equal to 20.') end if !@description.nil? && @description.to_s.length > 30 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 30.') end if !@quantity.nil? && @quantity < 1 invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.') end if !@unit_measure.nil? && @unit_measure.to_s.length > 3 invalid_properties.push('invalid value for "unit_measure", the character length must be smaller than or equal to 3.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 153 |
# File 'lib/openapi_client/models/purchase_cards_level3_line_items.rb', line 146 def valid? return false if !@commodity_code.nil? && @commodity_code.to_s.length > 4 return false if !@product_code.nil? && @product_code.to_s.length > 20 return false if !@description.nil? && @description.to_s.length > 30 return false if !@quantity.nil? && @quantity < 1 return false if !@unit_measure.nil? && @unit_measure.to_s.length > 3 true end |